-- buff总览界面
checkRequire("Lua_BuffVo");
checkRequire("Lua_MonsterConfigData");
Lua_FightOverallBuffWindow = class("Lua_FightOverallBuffWindow", Lua_Window)
function Lua_FightOverallBuffWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_FightOverallBuffWindow";
	self.skinName = "FightOverallBuffWindow_skin"
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_FightOverallBuffWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.attackerList = Lua_DragList.new(self.content, 320, 551, Lua_AxisDefine.Vertical);
	self.attackerList:setSiblingIndex(4);
	self.attackerList:setLocation(-162, -20, 0);
	self.attackerList.canDrag = false;
	self.attackerList:setListCell(Lua_FightBuffInfoItem, 320, 81, 1);
	self.attackerList:setCellSpacing(0, 13);

	self.defenderList = Lua_DragList.new(self.content, 320, 551, Lua_AxisDefine.Vertical);
	self.defenderList:setSiblingIndex(4);
	self.defenderList:setLocation(162, -20, 0);
	self.defenderList.canDrag = false;
	self.defenderList:setListCell(Lua_FightBuffInfoItem, 320, 81, 1);
	self.defenderList:setCellSpacing(0, 13);

	self:addLuaEvent("refresh_fight_buff", self, self.updateShowInfo);
end

function Lua_FightOverallBuffWindow:dispose()
	if self.attackerList ~= nil then
		self.attackerList:dispose();
		self.attackerList = nil;
	end
	if self.defenderList ~= nil then
		self.defenderList:dispose();
		self.defenderList = nil;
	end
	self:superCall("dispose");
end

function Lua_FightOverallBuffWindow:showWin(param)
	self:superCall("showWin", param);
	if param == nil then
		self:hide();
		return;
	end

	local recordVo = DataCenter.fightData:getRecordVoById(param);
	if recordVo == nil then
		self:hide();
		return;
	end

	if self.recordId ~= param then
		self.recordId = param;

		if recordVo.attacker == nil or tonumber(recordVo.attacker.id) <= 0 then
			self.attackerName.text = nil;
		else
			self.attackerName.text = recordVo.attacker.name;
		end

		if recordVo.defender == nil or tonumber(recordVo.defender.id) <= 0 then
			self.defenderName.text = nil;
		else
			self.defenderName.text = recordVo.defender.name;
		end

		local attackArr = Array();
		local attackList = DataCenter.thingData:getThingIdsByFormationType(param, Lua_FightDefine.FIGHT_ATTACKER);
		if attackList ~= nil then
			for i = 1, attackList:getSize() do
				local thing = DataCenter.thingData:getThingPlayer(recordVo.sceneId, param, attackList[i]);
				if thing and not thing.data.isSummoned and (thing.kind == Lua_ThingDefine.HERO or thing.kind == Lua_ThingDefine.MONSTER) then
					attackArr:add({ index = i, attacker = 1, sceneId = recordVo.sceneId, recordId = param, playerId = attackList[i] });
				end
			end
		end
		self.attackerList:setArrayData(attackArr);

		local defendArr = Array();
		local defendList = DataCenter.thingData:getThingIdsByFormationType(param, Lua_FightDefine.FIGHT_DEFENDER);
		if defendList ~= nil then
			for i = 1, defendList:getSize() do
				local thing = DataCenter.thingData:getThingPlayer(recordVo.sceneId, param, defendList[i]);
				if thing and not thing.data.isSummoned and (thing.kind == Lua_ThingDefine.HERO or thing.kind == Lua_ThingDefine.MONSTER) then
					defendArr:add({ index = i, sceneId = recordVo.sceneId, recordId = param, playerId = defendList[i] });
				end
			end
		end
		self.defenderList:setArrayData(defendArr);
	else
		self.attackerList:updateShowList();
		self.defenderList:updateShowList();
	end
end

function Lua_FightOverallBuffWindow:updateShowInfo()
	self.attackerList:updateShowList();
	self.defenderList:updateShowList();
end















Lua_FightBuffInfoItem = class("Lua_FightBuffInfoItem", Lua_ListCell);
function Lua_FightBuffInfoItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_FightBuffInfoItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemBg = UICreate.createUIAtlasImage(self.content, "fight_atlas_1", "xui_zd_widget_10", 0, 0, 320, 81);

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.66, 0.66, 0.66);
	self.itemIcon:setClick(self, self.onCheckBuff);
end

function Lua_FightBuffInfoItem:dispose()
	self:clearBuffIcon();
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_FightBuffInfoItem:setData(data)
	self.data = data;
	if data.attacker == 1 then
		self.itemIcon:setLocation(-110, 0, 0);
	else
		self.itemIcon:setLocation(110, 0, 0);
	end

	local thing = DataCenter.thingData:getThingPlayer(data.sceneId, data.recordId, data.playerId);
	self.thingData = thing.data;
	local heroId = tonumber(tostring(self.thingData.objId));
	if self.thingData.kind == Lua_ThingDefine.MONSTER then
		heroId = Lua_MonsterConfigData.getMonsterConfig(heroId).heroId;
	end
	local vo = Lua_HeroVo.new(heroId);
	vo.level = self.thingData.lvl;
	vo.clothesId = thing.fashionId;
	local config = DataCenter.heroUtil:getHeroAwakenStarConfigInfo(self.thingData.star);
	if config then
		vo.quality = config.quality;
		vo.quality_star = config.quality_star;
	end
	self.itemIcon:setData(vo);

	self:updateData();
end

function Lua_FightBuffInfoItem:updateData()
	self:returnIcon();
	if self.thingData == nil then
		return;
	end
	if tonumber(tostring(self.thingData.hp)) <= 0 then
		self.itemIcon:setMask(true);
		self:showDeadIcon(true);
	else
		self.itemIcon:setMask(false);
		self:showDeadIcon(false);
	end

	local count = self.thingData.buffCount;
	if count <= 0 then
		return;
	end

	count = count - 1;
	local dic = {};
    local buffId;
    local buffData;
    local key;
	for i = 0, count do
		buffId = self.thingData:getBuffIdByIdx(i);
		buffData = Lua_BuffConfigData.getConfigData(buffId);
		if buffData and not strIsNullOrEmpty(buffData.atlas) and not strIsNullOrEmpty(buffData.sprite) then
			key = buffData.main_type * 10000 + buffData.sub_type;
			if dic[key] == nil then
				local vo = Lua_BuffVo.new();
				vo.atlas = buffData.atlas;
				vo.sprite = buffData.sprite;
				vo.sortWeight = buffData.sort;
				vo.overlayNum = self.thingData:getBuffOverlayNumByIdx(i);
				dic[key] = vo;
			else
				dic[key].overlayNum = dic[key].overlayNum + self.thingData:getBuffOverlayNumByIdx(i);
			end
		end
	end

	local arr = Array();
	for _, v in pairs(dic) do
		arr:add(v);
	end
	arr:sort("sortWeight", false);

	local icon;
	for i = 1, arr:getSize() do
		if i > 8 then
			return;
		end

		icon = self:createIcon();
		if self.data.attacker == 1 then
			icon:setLocation(-40 + ((i - 1) % 4) * 45, 20 + Mathf.Floor((i - 1) / 4) * 40 * -1, 0);
		else
			icon:setLocation(40 - ((i - 1) % 4) * 45, 20 + Mathf.Floor((i - 1) / 4) * 40 * -1, 0);
		end
		icon:setData(arr[i]);
		icon:setClick(self, self.onCheckBuff);
	end
end

function Lua_FightBuffInfoItem:showDeadIcon(value)
	if value then
		if self.deadIcon == nil then
			self.deadIcon = UICreate.createUIAtlasImage(self.content, "fight_atlas_1", "xui_zd_word_6", 0, 0, 0, 0);
		end
		self.deadIcon:setEnable(true);
		if self.data.attacker == 1 then
			self.deadIcon:setLocation(-110, 0, 0);
		else
			self.deadIcon:setLocation(110, 0, 0);
		end
	else
		if self.deadIcon ~= nil then
			self.deadIcon:setEnable(false);
		end
	end
end

function Lua_FightBuffInfoItem:clearBuffIcon()
	if self.showList ~= nil then
		self.showList:dispose();
		self.showList:clear();
		self.showList = nil;
	end
	if self.hideList ~= nil then
		self.hideList:dispose();
		self.hideList:clear();
		self.hideList = nil;
	end
end

function Lua_FightBuffInfoItem:createIcon()
	if self.showList == nil or self.hideList == nil then
		return;
	end

	local len = self.hideList:getSize();
	local icon = nil;
	if len > 0 then
		icon = self.hideList:remove();
	end

	if icon == nil then
		icon = Lua_BuffIcon.new(self.content);
	end
	icon:setEnable(true);
	self.showList:add(icon);
	return icon;
end

function Lua_FightBuffInfoItem:returnIcon()
	if self.showList == nil then
		self.showList = Array();
	end
	if self.hideList == nil then
		self.hideList = Array();
	end
	local len = self.showList:getSize();
	local icon;
	while len > 0 do
		icon = self.showList:remove(len);
		icon:setEnable(false);
		self.hideList:add(icon)
		len = len - 1;
	end
end

function Lua_FightBuffInfoItem:onCheckBuff()
	if self.data == nil then
		return;
	end
	Lua_WindowUtil.openWin("Lua_FightBuffDetailsWindow", Lua_WinParam.ACTION_OPEN, self.data);
end