-- 战斗伤害总览
checkRequire("Lua_ArtifactSkillItem");
Lua_FightOverallHurtWindow = class("Lua_FightOverallHurtWindow", Lua_Window);
function Lua_FightOverallHurtWindow:ctor(p)
	self:superCall("ctor");

	self.layer = Lua_MainWinDefine.TIPS_WINDOW_LAYER;
	self.windowName = "Lua_FightOverallHurtWindow";
	self.skinName = "FightOverallHurtWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_FightOverallHurtWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.artifactArr = Array();
	self.beastArr = Array();

	self.defenderAvatar = Lua_AvatarItem.new(self.content);
	self.defenderAvatar:setSiblingIndex(7);
	self.defenderAvatar:setLocation(-276, 505, 0);
	self.defenderAvatar:setScale(0.66, 0.66, 1);

	self.attackerAvatar = Lua_AvatarItem.new(self.content);
	self.attackerAvatar:setSiblingIndex(11);
	self.attackerAvatar:setLocation(-276, -63, 0);
	self.attackerAvatar:setScale(0.66, 0.66, 1);

	self:addLuaEvent("FIGHT_TEAM_SELECT", self, self.onTeamSelected);
end

function Lua_FightOverallHurtWindow:dispose()
	self:stopTimer();
	if self.artifactArr then
		self.artifactArr:dispose();
		self.artifactArr:clear();
		self.artifactArr = nil;
	end
	if self.beastArr then
		self.beastArr:dispose();
		self.beastArr:clear();
		self.beastArr = nil;
	end
	if self.defenderAvatar ~= nil then
		self.defenderAvatar:dispose();
		self.defenderAvatar = nil;
	end
	if self.attackerAvatar ~= nil then
		self.attackerAvatar:dispose();
		self.attackerAvatar = nil;
	end
	if self.attackerHurtList ~= nil then
		self.attackerHurtList:dispose();
		self.attackerHurtList = nil;
	end
	if self.defenderHurtList ~= nil then
		self.defenderHurtList:dispose();
		self.defenderHurtList = nil;
	end
	if self.buttonList then
		self.buttonList:dispose();
		self.buttonList = nil;
	end
	if self.btnInfo then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	self.teamDic = nil;
	self:superCall("dispose");
	Lua_MsgUtil.callFunc("FIGHT_OVERALL_HURT_CLOSE")
end

function Lua_FightOverallHurtWindow:showWin(param)
	self:superCall("showWin", param);

	if param.selectIdx == nil then
		self.selectIdx = 1;
	    self:updateHurtInfo(param);
	else
		self.selectIdx = param.selectIdx;
		self:updateHurtInfo(param.hurtInfo);
	end
end

function Lua_FightOverallHurtWindow:updateHurtInfo(hurtInfo)
	if hurtInfo == nil then
		return;
	end

	local list = hurtInfo.hurt_collect_list; --伤害统计列表
	if list == nil or #list <= 0 then
		return;
	end

	if #list > 1 then
		-- 一种是车轮战，一种是胜场战。
		-- 根据轮次分，车轮战第一轮就是双方对打，第二轮是输方第二队打胜利方剩余单位。 胜利站就是第一轮是攻一队打守一队，第二轮就是攻二队打守二队。
		if self.btnInfo == nil then
			self.btnInfo = Array();
		else
			self.btnInfo:clear()
		end

		table.sort( list, function(a, b) return a.rotation < b.rotation end );
		self.teamDic = {};
		local info;
		for i = 1, #list do
			info = list[i];
			if info.aod_win > 0 then
				self.btnInfo:add({ textStr = LanUtil.formateStr(302005, convert_arab_to_chinese(info.rotation)) });
				self.teamDic[info.rotation] = info;
			end
		end

		if self.buttonList == nil then
			self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal)
			self.buttonList:setSiblingIndex(0);
			self.buttonList:setRectPivot(3);
			self.buttonList:setLocation(-325, -(self.winBg.height / 2 - 3), 0);
			self.buttonList:setButtonStyle("common_altas_1", "xui_common_tab_002", "xui_common_tab_001", 133, 77);
			self.buttonList:setButtonText(0, 10, "7A6A5F", "8F5123", 26, 26, Lua_MyUISettings.huakangFontName);
			self.buttonList:setButtonItem(133, 77);
			self.buttonList:setClickCallBack(self, self.onButtonClick)
		end
		self.buttonList:setData(self.btnInfo)
		self.buttonList:setSelected(1)
	else
		self:showHurtInfo(list[1]);
	end
end

function Lua_FightOverallHurtWindow:onButtonClick(index)
	self:initList();
	self:showHurtInfo(self.teamDic[index]);
end

function Lua_FightOverallHurtWindow:showHurtInfo(info)
	if info == nil then
		return;
	end

	self.defenderName.text = info.defender.name;
	self.defenderLevel.text = info.defender.level;
	self.defenderAvatar:setRoleDressUp(info.defender.dress_info);

	local list = info.defender.artifact_skill_list
	local idx = 0
	local item
	for i = 1, #list do
		idx = idx + 1
		item = self.artifactArr[idx]
		if item == nil then
			item = Lua_ArtifactSkillItem.new(self.content)
			item:setScale(0.6, 0.6, 1)
			self.artifactArr:add(item)
		end
		item:setLocation(35 + (i - 1) * 45, 505, 0)
		if list[i] == 1 then
			item:setSkillId(nil)
		else
			item:setSkillId(list[i])
		end
		item:hideLevel()
		item:hideEnergy()
	end

	self.attackerName.text = info.attacker.name;
	self.attackerLevel.text = info.attacker.level;
	self.attackerAvatar:setRoleDressUp(info.attacker.dress_info);

	list = info.attacker.artifact_skill_list
	for i = 1, #list do
		idx = idx + 1
		item = self.artifactArr[idx]
		if item == nil then
			item = Lua_ArtifactSkillItem.new(self.content)
			item:setScale(0.6, 0.6, 1)
			self.artifactArr:add(item)
		end
		item:setLocation(35 + (i - 1) * 45, -63, 0)
		if list[i] == 1 then
			item:setSkillId(nil)
		else
			item:setSkillId(list[i])
		end
		item:hideLevel()
		item:hideEnergy()
	end

	list = info.defender.strange_beasts_skill_list
	idx = 0
	for i = 1, #list do
		idx = idx + 1
		item = self.beastArr[idx]
		if item == nil then
			item = Lua_FightHurtBeastItem.new(self.content)
			item:setScale(0.6, 0.6, 1)
			self.beastArr:add(item)
		end
		item:setLocation(180 + (i - 1) * 45, 505, 0)
		item:setData(list[i])
	end

	list = info.attacker.strange_beasts_skill_list
	for i = 1, #list do
		idx = idx + 1
		item = self.beastArr[idx]
		if item == nil then
			item = Lua_FightHurtBeastItem.new(self.content)
			item:setScale(0.6, 0.6, 1)
			self.beastArr:add(item)
		end
		item:setLocation(180 + (i - 1) * 45, -63, 0)
		item:setData(list[i])
	end

	if info.aod_win == 1 then --1：攻方 2：守方
		self.defenderTitleBg:setAltas("fight_atlas_2", "xui_zd_widget_13");
		self.defenderName.effectColorStr = Lua_ColorDefine.transColor("314B6C");
		self.attackerTitleBg:setAltas("fight_atlas_2", "xui_zd_widget_12");
		self.attackerName.effectColorStr = Lua_ColorDefine.transColor("933C2E");
	else
		self.defenderTitleBg:setAltas("fight_atlas_2", "xui_zd_widget_12");
		self.defenderName.effectColorStr = Lua_ColorDefine.transColor("933C2E");
		self.attackerTitleBg:setAltas("fight_atlas_2", "xui_zd_widget_13");
		self.attackerName.effectColorStr = Lua_ColorDefine.transColor("314B6C");
	end

	local attackArr = Array();
	local defendArr = Array();
	local obj;
	local hurt;
	local cure;
	local bearHurt;
	local num;
	local maxHurt = -1;
	local maxCure = -1;
	local maxBearHurt = -1;
	local maxNum = -1;
	local maxIdx = -1;

	list = info.attacker_hurt_collect;
	if list ~= nil then
		for i = 1, #list do
			obj = list[i];
			hurt = tonumber(obj.hurt);
			cure = tonumber(obj.cure);
			bearHurt = tonumber(obj.bear_hurt);
			num = Mathf.Abs(hurt) + Mathf.Abs(cure) + Mathf.Abs(bearHurt);
			if maxHurt < hurt then
				maxHurt = hurt;
			end
			if maxCure < cure then
				maxCure = cure;
			end
			if maxBearHurt < bearHurt then
				maxBearHurt = bearHurt;
			end
			if obj.type ~= 3 and obj.type ~= 7 and maxNum < num then
				maxNum = num;
				maxIdx = i;
			end
		end

		for i = 1, #list do
			attackArr:add({ teamType = Lua_FightDefine.FIGHT_ATTACKER, isMvp = maxIdx == i,
				maxHurt = maxHurt, maxCure = maxCure, maxBearHurt = maxBearHurt, info = list[i], player = info.attacker });
		end
	end
	attackArr:sortf(self, self.onHurtSortFun)

	maxShuchu = -1;
	maxZhiliao = -1;
	maxChengshang = -1;
	maxNum = -1;
	maxIdx = -1;
	list = info.defender_hurt_collect;
	if list ~= nil then
		for i = 1, #list do
			obj = list[i];
			hurt = tonumber(obj.hurt);
			cure = tonumber(obj.cure);
			bearHurt = tonumber(obj.bear_hurt);
			num = Mathf.Abs(hurt) + Mathf.Abs(cure) + Mathf.Abs(bearHurt);
			if maxHurt < hurt then
				maxHurt = hurt;
			end
			if maxCure < cure then
				maxCure = cure;
			end
			if maxBearHurt < bearHurt then
				maxBearHurt = bearHurt;
			end
			if obj.type ~= 3 and obj.type ~= 7 and maxNum < num then
				maxNum = num;
				maxIdx = i;
			end
		end

		for i = 1, #list do
			defendArr:add({ teamType = Lua_FightDefine.FIGHT_DEFENDER, isMvp = maxIdx == i,
				maxHurt = maxHurt, maxCure = maxCure, maxBearHurt = maxBearHurt, info = list[i], player = info.defender });
		end
	end
	defendArr:sortf(self, self.onHurtSortFun)

	if self.defenderHurtList == nil then
		self.defenderHurtList = Lua_DragContainer.new(self.content, 640, 443, Lua_AxisDefine.Vertical);
		self.defenderHurtList:setLocation(0, 235, 0);
		self.defenderHurtList.canDrag = false;
		self.defenderHurtList:setCellSpacing(0, 5);
	end
	self.defenderHurtList:clearList();
	for i = 1, defendArr:getSize() do
		self.defenderHurtList:addSubContainer(Lua_FightHurtInfoItem, defendArr[i]);
	end
	self.defenderHurtList:updateChildPos();
	self.defenderHurtList:moveToIndex(1, true);

	if self.attackerHurtList == nil then
		self.attackerHurtList = Lua_DragContainer.new(self.content, 640, 443, Lua_AxisDefine.Vertical);
		self.attackerHurtList:setLocation(0, -330, 0);
		self.attackerHurtList.canDrag = false;
		self.attackerHurtList:setCellSpacing(0, 5);
	end
	self.attackerHurtList:clearList();
	for i = 1, attackArr:getSize() do
		self.attackerHurtList:addSubContainer(Lua_FightHurtInfoItem, attackArr[i]);
	end
	self.attackerHurtList:updateChildPos();
	self.attackerHurtList:moveToIndex(1, true);

	self:startTimer();
end

function Lua_FightOverallHurtWindow:onHurtSortFun(a, b)
	if a.info.type == b.info.type then
		if a.info.pos > b.info.pos then
			return false
		end
	elseif a.info.type ~= 3 and b.info.type == 3 then
		return false;
	elseif a.info.type ~= 7 and b.info.type == 7 then
		return false;
	elseif a.info.type > b.info.type then
		return false
	end
	return true
end

function Lua_FightOverallHurtWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_FightOverallHurtWindow", 0.02, self, self.onUpdateRate, nil, -1);
	end
end

function Lua_FightOverallHurtWindow:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onUpdateRate);
	end
end

function Lua_FightOverallHurtWindow:onUpdateRate()
	local arr;
	local len;
	local idx = 0;
	local bUpdateComplete = true;

	if self.attackerHurtList ~= nil then
		idx = 0;
		arr = self.attackerHurtList.showList;
		len = arr:getSize();
		for i = 1, len do
			if arr[i]:updateRate() == true then
				idx = idx + 1;
			end
		end

		if idx < len then
			bUpdateComplete = false;
		end
	end

	if self.defenderHurtList ~= nil then
		arr = self.defenderHurtList.showList;
		len = arr:getSize();
		for i = 1, len do
			if arr[i]:updateRate() == true then
				idx = idx + 1;
			end
		end

		if idx < len then
			bUpdateComplete = false;
		end
	end

	if bUpdateComplete == true then
		self:stopTimer();
	end
end

function Lua_FightOverallHurtWindow:initList()
	local arr;

	if self.attackerHurtList ~= nil then
		arr = self.attackerHurtList.showList;
		for i = 1, arr:getSize() do
			arr[i]:init();
		end
	end

	if self.defenderHurtList ~= nil then
		arr = self.defenderHurtList.showList;
		for i = 1, arr:getSize() do
			arr[i]:init();
		end
	end
end



















-- 伤害列表item
Lua_FightHurtInfoItem = class("Lua_FightHurtInfoItem", Lua_ListCell)
function Lua_FightHurtInfoItem:ctor(p)
	self:superCall("ctor", p, "FightHurtInfoItem_skin", false);
end

function Lua_FightHurtInfoItem:buildShowItem()
	self:superCall("buildShowItem");
	self.bar_1.typeValue = 3;
	self.bar_1.fillMethodValue = 0;
	self.bar_1.fillOrigin = 0;
	self.bar_2.typeValue = 3;
	self.bar_2.fillMethodValue = 0;
	self.bar_2.fillOrigin = 0;
	self.bar_3.typeValue = 3;
	self.bar_3.fillMethodValue = 0;
	self.bar_3.fillOrigin = 0;

	self:init();
end

function Lua_FightHurtInfoItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_FightHurtInfoItem:init()
	self.bTweenCompleted = false;

	self.startHurtValue = 0;
	self.targetHurtVal = 0;
	self.maxHurtValue = 1;

	self.startCureValue = 0;
	self.targetCureVal = 0;
	self.maxCureValue = 1;

	self.startBearValue = 0;
	self.targetBearVal = 0;
	self.maxBearValue = 1;
end

function Lua_FightHurtInfoItem:getWidth()
    return 640;
end

function Lua_FightHurtInfoItem:getHeight()
	return self.bg.height;
end

function Lua_FightHurtInfoItem:setData(data)
	self.data = data;
	self.mvpIcon:setEnable(data.isMvp);
	self:updateData();
	self:updateAvatar();
end

function Lua_FightHurtInfoItem:updateData()
	if self.data ~= nil then
		self.startHurtValue = 0;
		self.targetHurtVal = tonumber(self.data.info.hurt);
		self.maxHurtValue = self.data.maxHurt;
		self.value_1.text = numberTrans(self.targetHurtVal);
		self.bar_1:setMaxValue(self.maxHurtValue);

		if self.bTweenCompleted == false then
			self.bar_1:setValue(0);
		else
			self.bar_1:setValue(self.targetHurtVal);
		end

		self.startCureValue = 0;
		self.targetCureVal = tonumber(self.data.info.cure);
		self.maxCureValue = self.data.maxCure;
		self.value_2.text = numberTrans(self.targetCureVal);
		self.bar_2:setMaxValue(self.maxCureValue);

		if self.bTweenCompleted == false then
			self.bar_2:setValue(0);
		else
			self.bar_2:setValue(self.targetCureVal);
		end

		self.startBearValue = 0;
		self.targetBearVal = tonumber(self.data.info.bear_hurt);
		self.maxBearValue = self.data.maxBearHurt;
		self.value_3.text = numberTrans(self.targetBearVal);
		self.bar_3:setMaxValue(self.maxBearValue);
		
		if self.bTweenCompleted == false then
			self.bar_3:setValue(0);
		else
			self.bar_3:setValue(self.targetBearVal);
		end
	end
end

-- 更新头像
function Lua_FightHurtInfoItem:updateAvatar()
	self.bg:setAltas("fight_atlas_2", "xui_zd_widget_14");
	if self.itemIcon then
		self.itemIcon:setEnable(false);
	end
	self.avatarBg:setEnable(false);
	self.avatarIcon:setEnable(false);
	self.icon_1:setEnable(false);
	self.icon_2:setEnable(false);
	self.icon_3:setEnable(false);
	if self.data == nil or self.data.info == nil then
		return;
	end

	local heroId = tonumber(tostring(self.data.info.sort_id));
	local pType = self.data.info.type;
	if pType == 0 then -- 英雄
	elseif pType == 3 then -- 神器
		heroId = nil;
		self.bg:setAltas("fight_atlas_2", "xui_zd_widget_15");
		self.icon_1:setEnable(true);
		self.icon_2:setEnable(true);
		self.icon_3:setEnable(true);
		local list = self.data.player.artifact_skill_list;
		local index = 0;
		local skillId;
		while index < #list do
			index = index + 1;
			skillId = list[index];
			if skillId > 0 then
				break;
			end
		end
		local vo = Lua_SkillConfigData.getConfigData(skillId)
		vo = DataCenter.artifactData:getArtifactVoById(vo.artifactId)
		if vo == nil then
			self.avatarBg:setEnable(false);
			self.avatarIcon:setEnable(false);
		else
			self.avatarBg:setEnable(true);
			self.avatarIcon:setEnable(true);
			self.avatarBg:setAltas("common_altas_1", "xui_common_itembg_"..vo.color)
			self.avatarIcon:setAltas("raccoon_atlas_2", vo.id)
		end
	elseif pType == 7 then -- 异兽
		heroId = nil;
		self.bg:setAltas("fight_atlas_2", "xui_zd_widget_15");
		local list = self.data.player.strange_beasts_skill_list;
		local index = 0;
		local skillId;
		while index < #list do
			index = index + 1;
			skillId = list[index];
			if skillId > 0 then
				break;
			end
		end
		local config = Lua_SkillConfigData.getConfigData(skillId);
		if config == nil then
			self.avatarBg:setEnable(false);
			self.avatarIcon:setEnable(false);
		else
			config = Lua_StrangeBeastConfigData.getConfig(config.beastId);
			if config == nil then
				self.avatarBg:setEnable(false);
				self.avatarIcon:setEnable(false);
			else
				self.avatarBg:setEnable(true);
				self.avatarIcon:setEnable(true);
				self.avatarBg:setAltas("common_altas_1", "xui_common_itembg_"..config.color)
				self.avatarIcon:setAltas(config.atlas, config.sprite)
			end
		end
	else
		heroId = Lua_MonsterConfigData.getMonsterConfig(heroId).heroId;
	end
	self.bg:resetSize();

	if heroId ~= nil then
		local vo = Lua_HeroVo.new(heroId);
		vo.level = self.data.info.level;
		vo.quality = self.data.info.quality;
		vo.quality_star = self.data.info.quality_star;
		vo.clothesId = self.data.info.clothes_id;
		if self.itemIcon == nil then
			self.itemIcon = Lua_ItemIcon.new(self.content);
			self.itemIcon:setSiblingIndex(1);
			self.itemIcon:setScale(0.4, 0.4);
			self.itemIcon:setLocation(-275, 0, 0);
		end
		self.itemIcon:setEnable(true);
		self.itemIcon:setData(vo);
	end
end

function Lua_FightHurtInfoItem:updateRate()
	local isComplete = true;
	if self.targetHurtVal > 0 then
		if self.startHurtValue < self.targetHurtVal then
			self.startHurtValue = self.startHurtValue + (self.maxHurtValue / 30);
			if self.startHurtValue > self.targetHurtVal then
				self.startHurtValue = self.targetHurtVal;
			else
				isComplete = false;
			end
			self.bar_1:setValue(self.startHurtValue);
		end
	end

	if self.targetCureVal > 0 then
		if self.startCureValue < self.targetCureVal then
			self.startCureValue = self.startCureValue + (self.maxCureValue / 30);
			if self.startCureValue > self.targetCureVal then
				self.startCureValue = self.targetCureVal;
			else
				isComplete = false;
			end
			self.bar_2:setValue(self.startCureValue);
		end
	end 

	if self.targetBearVal > 0 then
		if self.startBearValue < self.targetBearVal then
			self.startBearValue = self.startBearValue + (self.maxBearValue / 30);
			if self.startBearValue > self.targetBearVal then
				self.startBearValue = self.targetBearVal;
			else
				isComplete = false;
			end
			self.bar_3:setValue(self.startBearValue);
		end
	end 

	self.bTweenCompleted = isComplete;
	return isComplete;
end










Lua_FightHurtBeastItem = class("Lua_FightHurtBeastItem", Lua_DisplayObject)
function Lua_FightHurtBeastItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_FightHurtBeastItem:buildShowItem()
	self:superCall("buildShowItem");

	self.bg = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 0, 0);
	self.icon = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 1, 0, 0);
	self.icon:setScale(0.55, 0.55, 1);
end

function Lua_FightHurtBeastItem:dispose()
	self:superCall("dispose");
end

function Lua_FightHurtBeastItem:setData(data)
	if data == nil or data == 0 then
		self.bg:setAltas("hero_embattle", "xui_zd_widget_5");
		self.icon:setEnable(false);
	else
		self.bg:setAltas("hero_embattle", "xui_zd_widget_6");
		local config = Lua_SkillConfigData.getConfigData(data);
		config = Lua_StrangeBeastConfigData.getConfig(config.beastId);
		if config == nil then
			self.icon:setEnable(false);
		else
			self.icon:setEnable(true);
			self.icon:setAltas(config.avatar_atlas, config.avatar_sprite);
		end
	end
end