Lua_FightBuffChooseWindow = class("Lua_FightBuffChooseWindow", Lua_Window);
function Lua_FightBuffChooseWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.TIPS_WINDOW_LAYER;
	self.windowName = "Lua_FightBuffChooseWindow";
	self.skinName = "FightBuffChooseWindow_skin";
	self.showBlackMask = true;
end

function Lua_FightBuffChooseWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("FIGHT_BUFF_SELECT", self, self.onBuffSelected);

	self.itemList = Lua_DragList.new(self.content, 720, 361, Lua_AxisDefine.Horizontal);
	self.itemList:setLocation(0, 73, 0);
	self.itemList:setListCell(Lua_FightBuffChooseItem, 240, 361, 1);
	self.itemList.canDrag = false;

	self.btnConfirm:addClickFuntion(self, self.onConfirm);
end

function Lua_FightBuffChooseWindow:dispose()
	self:endTimer();
	if self.data ~= nil then
		if self.second > 0 then
			DataCenter.fightData:setBuffChooseInfo(self.recordId, self.second, self.data)
		else
			DataCenter.fightData:onBuffChooseComplete(self.recordId, self.data)
		end
		self.data = nil
	end
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_FightBuffChooseWindow:showWin(param)
	self:superCall("showWin", param);
	DataCenter.fightData.bBuffChooseTimer = false
	self.recordId = tonumber(param.record_id);

	self.itemList:setArrayData(param.skill_id_list);
	self.itemList:setSelectClick(1);
	self.itemList:setSelected(1);
	
	local value = DataCenter.fightData.infinityHallBuffSec or 30
	self.second = Mathf.Floor(value)
	
	self:startTimer();
	self:onTimer();
end

function Lua_FightBuffChooseWindow:startTimer()
	if self.bTiming ~= true then
		self.bTiming = false;
		self:addTimer("Lua_FightBuffChooseWindow", 1, self, self.onTimer);
	end
end

function Lua_FightBuffChooseWindow:endTimer()
	if self.bTiming == true then
		self.bTiming = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_FightBuffChooseWindow:onTimer()
	self.second = self.second - 1;
	if self.second > 0 then
		self.timeText.text = LanUtil.formateStr(302006, tostring(self.second));
	else
		self:endTimer();
		self.timeText.text = nil;
		self:hide();
	end
end

function Lua_FightBuffChooseWindow:onBuffSelected(data)
	self.data = data;
end

function Lua_FightBuffChooseWindow:onConfirm(go)
	if self.data == nil or self.showData == nil then
		DataCenter.fightData:removeFight(self.recordId);
		self:hide()
	else
		local skillId = self.data
		self.data = nil
		DataCenter.fightData:onBuffChooseComplete(self.recordId, skillId)
	end
end




















Lua_FightBuffChooseItem = class("Lua_FightBuffChooseItem", Lua_ListCell);
function Lua_FightBuffChooseItem:ctor(p)
	self:superCall("ctor", p, "FightBuffChooseItem_skin");
end

function Lua_FightBuffChooseItem:buildShowItem()
	self:superCall("buildShowItem");

	self.selectBg:setEnable(false);
	self.maskBg:setEnable(false);

	self.dragContainer = Lua_DragContainer.new(self.content, 145, 100, Lua_AxisDefine.Vertical);
	self.dragContainer:setLocation(0, -80, 0);
	self:setSubList(self.dragContainer);
end

function Lua_FightBuffChooseItem:dispose()
	if self.dragContainer ~= nil then
		self.dragContainer:dispose();
		self.dragContainer = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_FightBuffChooseItem:setData(data)
	self.data = data;
	local config = Lua_SkillConfigData.getConfigData(data);
	if config == nil then
		return;
	end
	
	self.icon:setAltas(config.atlas, config.sprite);
	self.icon:resetSize();
	self.nameText.text = config.name;
	self.dragContainer:clearList();
	self.dragContainer:addSubContainer(Lua_FightBuffTextItem, config.white_des, true);
	self.dragContainer.canDrag = not self.dragContainer.isTheEnd;
end

function Lua_FightBuffChooseItem:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);
	self.selectBg:setEnable(bSelect);
	self.maskBg:setEnable(not bSelect);
	self.maskBg.alpha = 0.7;
end

function Lua_FightBuffChooseItem:onPressClick()
	if self.data == nil then
		return false;
	end
	Lua_MsgUtil.callFunc("FIGHT_BUFF_SELECT", self.data);
	return true;
end









































Lua_FightBuffTextItem = class("Lua_FightBuffTextItem", Lua_DragContainerItem);
function Lua_FightBuffTextItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_FightBuffTextItem:buildShowItem()
	self:superCall("buildShowItem");

	self.textField = UICreate.createLabel(self.content, nil, 0, 0, 145, 0, 18);
	self.textField.lineSpacing = 1.2;
	self.textField.verticalOverflowValue = 1;
end

function Lua_FightBuffTextItem:dispose()
	self:superCall("dispose");
end

function Lua_FightBuffTextItem:getWidth()
	return self.textField.width;
end

function Lua_FightBuffTextItem:getHeight()
	return self.textField.height;
end

function Lua_FightBuffTextItem:setData(data)
	self.textField.text = data;
	self.textField:resetSize();
end

function Lua_FightBuffTextItem:onPressClick()
	return nil, true;
end