Lua_FightArtifactPanel = class("Lua_FightArtifactPanel", Lua_DisplayObject)
function Lua_FightArtifactPanel:ctor(p)
	self:superCall("ctor", p, "FightArtifactPanel_skin")
end

function Lua_FightArtifactPanel:buildShowItem()
	self:superCall("buildShowItem")
end

function Lua_FightArtifactPanel:dispose()
	if self.uiEff then
		self.uiEff:dispose()
		self.uiEff = nil
	end
	if self.ownArtifacts then
		self.ownArtifacts:dispose()
		self.ownArtifacts:clear()
		self.ownArtifacts = nil
	end
	if self.enemyArtifacts then
		self.enemyArtifacts:dispose()
		self.enemyArtifacts:clear()
		self.enemyArtifacts = nil
	end
	self:superCall("dispose")
end

-- 1.攻方：自己：根据功能开启显示而显示。非自己PVE：无神器且无异兽时，战斗界面隐藏敌方的神器和异兽信息
-- 2.敌方：PVE当敌方无神器且无异兽时，战斗界面隐藏敌方的神器和异兽信息。PVP默认显示
-- 3.录像：双方默认开启
function Lua_FightArtifactPanel:setData(recordId)
	local player = DataCenter.fightData:getFightPlayerById(recordId);
	local vo = DataCenter.fightData:getRecordVoById(recordId);

	if player.attackerArtifact ~= nil then
		self.ownObject:SetActive(true);
		self:setOwnData(player.curRound, player.artifactEnergy, player.attackerArtifact, vo.ownType == Lua_FightDefine.FIGHT_ATTACKER);
	else
		self.ownObject:SetActive(false);
	end

	if player.defenderArtifact ~= nil then
		self.enemyObject:SetActive(true);
		self:setEnemyData(player.curRound, 0, player.defenderArtifact, vo.ownType == Lua_FightDefine.FIGHT_DEFENDER);
	else
		self.enemyObject:SetActive(false);
	end
end

function Lua_FightArtifactPanel:setOwnData(curRound, energy, skillList, isSelf)
	if self.uiEff == nil then
		self.uiEff = UICreate.createUIEffect(self.ownObject, "/effects/uiEffects/ui_zd_hxnl_0001", "ui_zd_hxnl_0001", -324, 35)
		self.uiEff.siblingIndex = 1
		self.uiEff.anchorValue = 7;
	end
	if energy == nil or energy <= 0 then
		self.ownEnergyText:setEnable(false);
	else
		self.ownEnergyText:setEnable(true);
		self.ownEnergyText.text = energy
	end

	if self.ownArtifacts == nil then
		self.ownArtifacts = Array()
		local list = DataCenter.artifactUtil.unlock_level
		local item
		for i = 1, #list do
			item = Lua_OwnArtifactItem.new(self.ownObject)
			item:setLocation(-250.5 + (i - 1) * 85.5, 45, 0)
			item:setIndex(i, list[i])
			item:setData(curRound, nil, isSelf)
			self.ownArtifacts:add(item)
		end
	else
		for i = 1, 3 do
			self.ownArtifacts[i]:setData(curRound, nil, isSelf)
		end		
	end

	if skillList == nil then
		return;
	end
	local info
	for i = 1, #skillList do
		info = skillList[i]
		if info.index and info.index > 0 then
			self.ownArtifacts[info.index]:setData(curRound, info, isSelf)
		end
	end
end

function Lua_FightArtifactPanel:setEnemyData(curRound, energy, artifactSkill, isSelf)
	if self.enemyArtifacts == nil then
		self.enemyArtifacts = Array()
		local list = DataCenter.artifactUtil.unlock_level
		local item
		for i = 1, #list do
			item = Lua_EnemyArtifactItem.new(self.enemyObject)
			item:setScale(0.66, 0.66, 1)
			item:setLocation(230 + (i - 1) * 50, -130, 0)
			item:setIndex(i, 0)
			item:setData(curRound, nil)
			self.enemyArtifacts:add(item)
		end
	else
		for i = 1, 3 do
			self.enemyArtifacts[i]:setData(curRound, nil)
		end
	end

	if artifactSkill == nil then
		return;
	end
	local info
	for i = 1, #artifactSkill do
		info = artifactSkill[i]
		if info.index and info.index > 0 then
			self.enemyArtifacts[info.index]:setData(curRound, info, isSelf)
		end
	end
end











Lua_FightArtifactItem = class("Lua_FightArtifactItem", Lua_DisplayObject)
function Lua_FightArtifactItem:ctor(p)
	self:superCall("ctor", p, "FightArtifactItem_skin")
end

function Lua_FightArtifactItem:buildShowItem()
	self:superCall("buildShowItem")

	self.maskImg:setEnable(false)
	self.icon:setEnable(false)
	self.energyIcon:setEnable(false)
	self.energyText:setEnable(false)
	self.coolText:setEnable(false)
end

function Lua_FightArtifactItem:dispose()
	self.data = nil
	self:superCall("dispose")
end

function Lua_FightArtifactItem:setIndex(index, unlockLv)
	self.index = index
	self.unlockLv = unlockLv
	if unlockLv > DataCenter.roleData.level then
		self.bg:setAltas("hero_embattle", "xui_zd_widget_6")
		self.unlockText:setEnable(true)
	else
		self.bg:setAltas("hero_embattle", "xui_zd_widget_5")
		self.unlockText:setEnable(false)
	end
end

function Lua_FightArtifactItem:setData(curRound, data, isSelf)
	self.curRound = curRound
	self.data = data
	self.isSelf = isSelf;
	self:updateData()
end

function Lua_FightArtifactItem:updateData()
	if self.data and self.data.skill_id > 0 then
		self.bg:setAltas("hero_embattle", "xui_zd_widget_6")
		self.icon:setEnable(true)
		self.energyIcon:setEnable(true)
		self.energyText:setEnable(true)

		local config = Lua_SkillConfigData.getConfigData(self.data.skill_id)
		self.icon:setAltas(config.atlas, config.sprite)
		self.energyText.text = config.costEnergy

		local value = self.data.active_round - self.curRound
		if self.data.is_cool == 1 and value > 0 then
			self.maskImg:setEnable(true)
			self.maskImg:setAltas("common_altas_4", "xui_common_widget_038")
			self.maskImg:setScale(0.7, 0.7, 1)
			self.coolText:setEnable(true)
			self.coolText.text = value
		else
			self.maskImg:setEnable(false)
			self.coolText:setEnable(false)
		end
		self.unlockText:setEnable(false)
	else
		if self.isSelf and self.unlockLv > DataCenter.roleData.level then
			self.bg:setAltas("hero_embattle", "xui_zd_widget_6")
			self.icon:setEnable(false)
			self.maskImg:setEnable(false)
			self.energyIcon:setEnable(false)
			self.energyText:setEnable(false)
			self.coolText:setEnable(false)
			self.unlockText:setEnable(true)
		else
			self.bg:setAltas("hero_embattle", "xui_zd_widget_5")
			self.icon:setEnable(false)
			self.maskImg:setEnable(false)
			self.energyIcon:setEnable(false)
			self.energyText:setEnable(false)
			self.coolText:setEnable(false)
			self.unlockText:setEnable(false)
		end
	end
end










Lua_OwnArtifactItem = class("Lua_OwnArtifactItem", Lua_FightArtifactItem)

function Lua_OwnArtifactItem:buildShowItem()
	self:superCall("buildShowItem")
	self:addLuaEvent("FIGHT_ARTIFACT_RELEASE_A", self, self.onRelease)
	self:addLuaEvent("FIGHT_ARTIFACT_COMPLETE_A", self, self.onComplete)
end

function Lua_OwnArtifactItem:dispose()
	if self.uiEff then
		self.uiEff:dispose()
		self.uiEff = nil
	end
	self:superCall("dispose")
end

function Lua_OwnArtifactItem:onRelease(skillId)
	if self.data and self.data.skill_id == skillId then
		if self.uiEff == nil then
			self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_zd_hxnl_0002", "ui_zd_hxnl_0002", 0, 0)
		else
			self.uiEff:setEnable(false)
		end
	else
		if self.uiEff then
			self.uiEff:setEnable(false)
		end
	end
end

function Lua_OwnArtifactItem:onComplete(skillId)
	if self.uiEff then
		self.uiEff:setEnable(false)
	end
	self:updateData()
end










Lua_EnemyArtifactItem = class("Lua_EnemyArtifactItem", Lua_FightArtifactItem)

function Lua_EnemyArtifactItem:buildShowItem()
	self:superCall("buildShowItem")
	self:addLuaEvent("FIGHT_ARTIFACT_COMPLETE_D", self, self.onComplete)
end

function Lua_EnemyArtifactItem:onComplete(skillId)
	self:updateData()
end