Lua_FightBeastsPanel = class("Lua_FightBeastsPanel", Lua_DisplayObject)
function Lua_FightBeastsPanel:ctor(p)
	self:superCall("ctor", p, "FightBeastsPanel_skin");
end

function Lua_FightBeastsPanel:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_FightBeastsPanel:dispose()
	if self.ownBeasts then
		self.ownBeasts:dispose();
		self.ownBeasts:clear();
		self.ownBeasts = nil;
	end
	if self.enemyBeasts then
		self.enemyBeasts:dispose();
		self.enemyBeasts:clear();
		self.enemyBeasts = nil;
	end
	self:superCall("dispose")
end

function Lua_FightBeastsPanel:setData(recordId)
	local player = DataCenter.fightData:getFightPlayerById(recordId);
	local vo = DataCenter.fightData:getRecordVoById(recordId);

	if player.attackerBeasts ~= nil then
		self.ownObject:SetActive(true);
		self:setOwnData(player.curRound, player.attackerBeasts, vo.ownType == Lua_FightDefine.FIGHT_ATTACKER);
		if player.attackerArtifact == nil then
			LuaUtil.setObjPos(self.ownObject, 0, -102, 0);
		else
			LuaUtil.setObjPos(self.ownObject, 0, 0, 0);
		end
	else
		self.ownObject:SetActive(false);
	end

	if player.defenderBeasts ~= nil then
		self.enemyObject:SetActive(true);
		self:setEnemyData(player.curRound, player.defenderBeasts, vo.ownType == Lua_FightDefine.FIGHT_DEFENDER);
		if player.defenderArtifact == nil then
			LuaUtil.setObjPos(self.enemyObject, 0, 90, 0);
		else
			LuaUtil.setObjPos(self.enemyObject, 0, 0, 0);
		end
	else
		self.enemyObject:SetActive(false);
	end
end

function Lua_FightBeastsPanel:setOwnData(curRound, skillList, isSelf)
	if self.ownBeasts == nil then
		self.ownBeasts = Array();
		local item;
		for i = 1, 3 do
			item = Lua_FightBeastItem.new(self.ownObject);
			item:setLocation(-325 + (i - 1) * 50, 140, 0);
			item:setData(i, curRound, nil, isSelf);
			self.ownBeasts:add(item);
		end
	else
		for i = 1, 3 do
			self.ownBeasts[i]:setData(i, curRound, nil, isSelf);
		end		
	end

	if skillList == nil then
		return;
	end
	local info
	for i = 1, #skillList do
		info = skillList[i];
		if info.index and info.index > 0 then
			self.ownBeasts[info.index]:setData(info.index, curRound, info, isSelf);
		end
	end
end

function Lua_FightBeastsPanel:setEnemyData(curRound, beastsSkill, isSelf)
	if self.enemyBeasts == nil then
		self.enemyBeasts = Array();
		local item;
		for i = 1, 3 do
			item = Lua_FightBeastItem.new(self.enemyObject);
			item:setLocation(225 + (i - 1) * 50, -205, 0);
			item:setData(i, curRound, nil, isSelf);
			self.enemyBeasts:add(item);
		end
	else
		for i = 1, 3 do
			self.enemyBeasts[i]:setData(i, curRound, nil, isSelf);
		end		
	end

	if beastsSkill == nil then
		return;
	end
	local info
	for i = 1, #beastsSkill do
		info = beastsSkill[i];
		if info.index and info.index > 0 then
			self.enemyBeasts[info.index]:setData(info.index, curRound, info, isSelf);
		end
	end
end










Lua_FightBeastItem = class("Lua_FightBeastItem", Lua_DisplayObject)
function Lua_FightBeastItem:ctor(p)
	self:superCall("ctor", p, "FightBeastItem_skin");
end

function Lua_FightBeastItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_FightBeastItem:dispose()
	self:superCall("dispose");
end

function Lua_FightBeastItem:setData(index, curRound, data, isSelf)
	if data and data.skill_id > 0 then
		local config = Lua_SkillConfigData.getConfigData(data.skill_id);
		config = Lua_StrangeBeastConfigData.getConfig(config.beastId);
		self.icon:setEnable(true);
		if config == nil then
			self.bg:setAltas("common_altas_5", "xui_ys_itembg_0");
			self.icon:setAltas("hero_embattle", "xui_hbtt_button_22");
			self.icon:SetDimensions(36, 36);
			self.icon:setScale(0.6, 0.6, 1);
		else
			self.bg:setAltas(config.embattle_bg_atlas, config.embattle_bg_sprite);
			self.icon:setAltas(config.embattle_atlas, config.embattle_sprite);
			self.icon:SetDimensions(41, 56);
			self.icon:setScale(1, 1, 1);
		end

		local value = data.active_round - curRound;
		if data.is_cool == 1 and value > 0 then
			self.maskImg:setEnable(true);
			self.coolText:setEnable(true);
			self.coolText.text = value;
		else
			self.maskImg:setEnable(false);
			self.coolText:setEnable(false);
		end
		self.unlockIcon:setEnable(false);
	else
		self.bg:setAltas("common_altas_5", "xui_ys_itembg_0");
		local state = DataCenter.strangeBeastData:checkLineupState(1, index);
		if not isSelf or state then
			self.icon:setEnable(true);
			self.icon:setAltas("hero_embattle", "xui_hbtt_button_22");
			self.icon:SetDimensions(36, 36);
			self.icon:setScale(0.6, 0.6, 1);
			self.maskImg:setEnable(false);
			self.coolText:setEnable(false);
			self.unlockIcon:setEnable(false);
		else
			self.icon:setEnable(false);
			self.maskImg:setEnable(false);
			self.coolText:setEnable(false);
			self.unlockIcon:setEnable(true);
		end
	end
end