Lua_FightBossHurtPanel = class("Lua_FightBossHurtPanel", Lua_DisplayObject)
function Lua_FightBossHurtPanel:ctor(p)
    self:superCall("ctor", p, "FightBossHurtPanel_skin");
end

function Lua_FightBossHurtPanel:buildShowItem()
    self:superCall("buildShowItem");
    self:addLuaEvent("FIGHT_BOSS_HURT_UPDATE", self, self.onHurtUpdate);

    self.wait_time = 0;
    self.aniWait = 0.2;

    self.curHurt = 0;
    self.totalHurt = 0;
    self.maxHurt = 1;
    self.maxValue = 1;
    self.showTarget = 1;
    self.showValue = 0;
    self.secondTarget = 0;
    self.addValue = 0;
    self.addValueStep = 1;
    self.speedRate = 1
    
    self.hurtBar:createSecondBar("chaos_forest_altas", "ui_hdsl_progress_003_f");
    self.hurtBar.typeValue = 3;
    self.hurtBar.fillMethodValue = 0;
    self.hurtBar.fillOrigin = 0;
    self.hurtBar:setSecondMaxValue(self.maxValue);
    self.hurtBar:setSecondValue(self.showValue);
    self.hurtBar:setMaxValue(self.maxValue);
    self.hurtBar:setValue(self.showValue);
end

function Lua_FightBossHurtPanel:dispose()
    self:endTimer();
    self:clearBuffIcon();
    self:superCall("dispose");
end

function Lua_FightBossHurtPanel:setData(recordId)
    local recordVo = DataCenter.fightData:getRecordVoById(recordId);
    self.templateId = recordVo.templateId;

    self.stageId = recordVo.stageId;
    if self.templateId == Lua_FightDefine.TEMPLATE_ID_CHAOSFOREST then -- 幽暗森林
        local config = DataCenter.chaosForestUtil:getLevelConfig(recordVo.stageId);
        self:setBossInfo(config.name, config.monster_id);
    elseif self.templateId == Lua_FightDefine.TEMPLATE_ID_LEAGUEDUELBOSS then -- 联盟BOSS
        self.boxIcon:setEnable(false);
        self:setBossInfo(recordVo.defender.name, recordVo.defender.id);
    elseif self.templateId == Lua_FightDefine.TEMPLATE_ID_BOSSCHALLENGE then -- BOSS挑战血条伤害
        self:setBossInfo(recordVo.defender.name, DataCenter.bossChallengeData.monster_id);
    elseif self.templateId == Lua_FightDefine.TEMPLATE_ID_HEROCHALLENGE then -- 英雄挑战血条伤害
        self:setBossInfo(recordVo.defender.name, DataCenter.heroChallengeData.monster_id);
    elseif self.templateId == Lua_FightDefine.TEMPLATE_ID_HEROTRIAL_ENDLESS then -- 新英雄英雄试炼无限模式血条伤害
        self.boxIcon:setEnable(false);
        self:setBossInfo(recordVo.defender.name, DataCenter.newHeroActData.heroTrialMonsterId);
    elseif self.templateId == Lua_FightDefine.TEMPLATE_ID_SPECIAL_LAST_DIVINEDOMAINTRIAL and 
        DataCenter.divineDomainTrialUtil:checkHurtFight(self.stageId) then -- 神域试炼特殊副本最后一关：伤害挑战
        self.boxIcon:setEnable(false);
        self:setBossInfo(recordVo.defender.name, recordVo.defender.id);
    end

    self.speedRate = recordVo.speedRate;
    self:setHurtValue(recordVo.bossHurt);
end

function Lua_FightBossHurtPanel:setSpeedRate(value)
    self.speedRate = value;
end

function Lua_FightBossHurtPanel:setBossInfo(name, monsterId)
    self.nameText.text = name;

    local monsterConfig = Lua_MonsterPlayerConfigData.getConfigData(monsterId);
    monsterId = monsterConfig.fighter_list[1][1][1];
    monsterConfig = Lua_MonsterConfigData.getMonsterConfig(monsterId);
    self.icon:setAltas(monsterConfig.avatar_atlas_1, monsterConfig.avatar_sprite_1);
end

function Lua_FightBossHurtPanel:setHurtValue(value)
    self.curHurt = value;
    self.totalHurt = value;

    local index, curValue, prevValue, isFinally = self:getMaxHurt();
    self.maxHurt = curValue;
    self.maxValue = curValue - prevValue;
    self.showValue = self.totalHurt - prevValue;
    self.isFinally = isFinally;

    self.stepText.text = LanUtil.formateStr(10043, tostring(index));
    self.hurtBar:setSecondMaxValue(self.maxValue);
    self.hurtBar:setSecondValue(self.showValue);
    self.hurtBar:setMaxValue(self.maxValue);
    self.hurtBar:setValue(self.showValue);
    if isFinally then
        self.hurtBar:setText(LanUtil.formateStr(10044, tostring(self.maxHurt), tostring(self.maxHurt)));
    else
        self.hurtBar:setText(LanUtil.formateStr(10044, tostring(self.totalHurt), tostring(self.maxHurt)));
    end
end

function Lua_FightBossHurtPanel:getMaxHurt()
    if self.templateId == Lua_FightDefine.TEMPLATE_ID_BOSSCHALLENGE then -- BOSS挑战血条伤害
        return DataCenter.bossChallengeData:getFightShowInfo(self.totalHurt);
    elseif self.templateId == Lua_FightDefine.TEMPLATE_ID_HEROCHALLENGE then -- 英雄挑战血条伤害
        return DataCenter.heroChallengeData:getFightShowInfo(self.totalHurt);
    elseif self.templateId == Lua_FightDefine.TEMPLATE_ID_HEROTRIAL_ENDLESS then -- 新英雄英雄试炼无限模式血条伤害
        return DataCenter.newHeroActData:getFightShowInfo(self.totalHurt);
     elseif self.templateId == Lua_FightDefine.TEMPLATE_ID_SPECIAL_LAST_DIVINEDOMAINTRIAL and 
        DataCenter.divineDomainTrialUtil:checkHurtFight(self.stageId) then -- 神域试炼特殊副本最后一关：伤害挑战
        return DataCenter.divineDomainTrialUtil:getFightShowInfo(self.totalHurt, self.stageId);
    end
    return DataCenter.chaosForestUtil:getMaxHurt(self.totalHurt);
end

function Lua_FightBossHurtPanel:onHurtUpdate(value)
    self.totalHurt = self.totalHurt + value;

    if self.addValue == nil or self.addValue <= 0 then
        self.addValue = 0;
    end
    self.addValue = self.addValue + value;
    self.addValueStep = self.addValue / 1;

    if (self.maxValue - self.showValue) <= self.addValue then
        self.secondTarget = self.maxValue;
    else
        self.secondTarget = self.secondTarget + value;
    end

    self.wait_time = self.aniWait;
    self.startTime = getTime();
    self:startTimer();
end

function Lua_FightBossHurtPanel:startTimer()
    if self.bTimer ~= true then
        self.bTimer = true;
        self:addTimer("Lua_FightBossHurtPanel", 0.01, self, self.onTimer, nil, -1);
    end
end

function Lua_FightBossHurtPanel:endTimer()
    if self.bTimer == true then
        self.bTimer = false;
        self:removeTimer(self, self.onTimer);
    end
end

function Lua_FightBossHurtPanel:onTimer()
    local dt;
    if self.wait_time > 0 then
        self.hurtBar:setSecondMaxValue(self.maxValue);
        self.hurtBar:setSecondValue(self.secondTarget);

        dt = getTime() - self.startTime;
        self.wait_time = self.wait_time - dt;
        if self.wait_time <= 0 then
            self.wait_time = 0;
        end
        self.startTime = getTime();
    else
        if self.addValue <= 0 then
            self:endTimer();
            return;
        end

        local t = getTime();
        dt = (t - self.startTime) *  self.speedRate;
        self.startTime = t;

        local num = self.addValueStep * dt;
        self.addValue = self.addValue - num;
        if self.addValue <= 0 then
            num = num + self.addValue;
        end
        self.showValue = self.showValue + num;

        if self.showValue >= self.maxValue then
            self.showValue = self.showValue - self.maxValue;
            
            local index, curValue, prevValue, isFinally = self:getMaxHurt();
            self.stepText.text = LanUtil.formateStr(10043, tostring(index));
            self.maxHurt = curValue;
            self.maxValue = curValue - prevValue;
            self.isFinally = isFinally;

            self.secondTarget = 0;
            self.hurtBar:setSecondValue(self.secondTarget);
            if self.addValue > self.maxValue then
                self.secondTarget = self.maxValue;
            else
                self.secondTarget = self.addValue;
            end
            self.wait_time = self.aniWait;
            self.startTime = getTime();
        end

        if self.isFinally and self.curHurt > self.maxHurt then
            self:showMaxHurt();
        else
            self.hurtBar:setMaxValue(self.maxValue);
            self.hurtBar:setPercent(self.showValue / self.maxValue);
        end

        self.curHurt = self.curHurt + num;
        if self.curHurt > self.totalHurt then
            self.curHurt = self.totalHurt;
        end

        self.hurtBar:setText(LanUtil.formateStr(10044, tostring(getPreciseDecimal(self.curHurt, 0)), tostring(self.maxHurt)));
    end
end

function Lua_FightBossHurtPanel:showMaxHurt()
    self.hurtBar:setSecondMaxValue(1);
    self.hurtBar:setSecondValue(1);
    self.hurtBar:setMaxValue(1);
    self.hurtBar:setValue(1);
    self.hurtBar:setText(LanUtil.formateStr(10044, tostring(self.maxHurt), tostring(self.maxHurt)));
end

function Lua_FightBossHurtPanel:updateBuff(data)
    self:returnBuffIcon();
    if data == nil or data.buffCount <= 0 then
        return;
    end

    local count = data.buffCount - 1;
    local dic = {};
    local len = 0;
    local buffId;
    local buffData;
    local key;
    for i = 0, count do
        buffId = data:getBuffIdByIdx(i);
        buffData = Lua_BuffConfigData.getConfigData(buffId);
        if buffData and not strIsNullOrEmpty(buffData.atlas) and not strIsNullOrEmpty(buffData.sprite) then
            key = buffData.main_type * 10000 + buffData.sub_type;
            if dic[key] == nil then
                local vo = Lua_BuffVo.new();
                vo.atlas = buffData.atlas;
                vo.sprite = buffData.sprite;
                vo.sortWeight = buffData.sort;
                vo.overlayNum = data:getBuffOverlayNumByIdx(i);
                dic[key] = vo;
                len = len + 1;
            else
                dic[key].overlayNum = dic[key].overlayNum + data:getBuffOverlayNumByIdx(i);
            end
        end
    end

    local arr = Array();
    for _, v in pairs(dic) do
        arr:add(v);
    end
    arr:sort("sortWeight", false);

    local icon;
    for i = 1, len do
        if i > DataCenter.fightUtil.fightBuffShowNum then
            return;
        end
        icon = self:createBuffIcon();
        icon:setLocation(-130 + (i - 1) * 40, -245, 0);
        icon:setData(arr[i]);
    end
end

function Lua_FightBossHurtPanel:clearBuffIcon()
    if self.showList ~= nil then
        self.showList:dispose();
        self.showList:clear();
        self.showList = nil;
    end
    if self.hideList ~= nil then
        self.hideList:dispose();
        self.hideList:clear();
        self.hideList = nil;
    end
end

function Lua_FightBossHurtPanel:createBuffIcon()
    if self.showList == nil then
        self.showList = Array();
    end
    if self.hideList == nil then
        self.hideList = Array();
    end

    local len = self.hideList:getSize();
    local icon = nil;
    if len > 0 then
        icon = self.hideList:remove();
    end

    if icon == nil then
        icon = Lua_BuffIcon.new(self.content);
    end
    icon:setEnable(true);
    self.showList:add(icon);
    return icon;
end

function Lua_FightBossHurtPanel:returnBuffIcon()
    if self.showList == nil or self.hideList == nil then
        return;
    end

    local len = self.showList:getSize();
    local icon;
    while len > 0 do
        icon = self.showList:remove(len);
        icon:setEnable(false);
        self.hideList:add(icon)
        len = len - 1;
    end
end