Lua_FightBossInfoPanel = class("Lua_FightBossInfoPanel", Lua_DisplayObject)
function Lua_FightBossInfoPanel:ctor(p)
    self:superCall("ctor", p, "FightBossInfoPanel_skin")
end

function Lua_FightBossInfoPanel:buildShowItem()
    self:superCall("buildShowItem")
    self.healthBar = Lua_FightHpBar.new(self.content, "fight_atlas_1", "xui_jmd_Progress _02_b", "xui_jmd_Progress _02_f", 407, 27)
    self.healthBar:setLocation(19, -12, 0)
    self.healthBar:createSecondBar("fight_atlas_1", "xui_jmd_Progress _03_f3") -- 回血
    self.healthBar:createAnimationBar("fight_atlas_1", "xui_jmd_Progress _03_f1") -- 扣血
    self.healthBar:setSiblingIndex(1)
    self.healthBar:setBarOffset(0, 0)
    self.healthBar:init()
    self.healthBar.timerName = "THINGPLAYER_HP"
end

function Lua_FightBossInfoPanel:dispose()
    if self.healthBar then
        self.healthBar:dispose()
        self.healthBar = nil
    end
    self:clearBuffIcon()
    self:superCall("dispose")
end

function Lua_FightBossInfoPanel:setData(data)
    local objId = tonumber(tostring(data.objId))
    local configData = Lua_MonsterConfigData.getMonsterConfig(objId)
    self.nameText.text = configData.name
    self.nameText:resetSize()
    self.icon:setAltas(configData.avatar_atlas_1, configData.avatar_sprite_1)
    self.campIcon:setAltas("common_altas_2", "xui_common_attribute_"..(configData.heroVo.campType + 6));

    local maxHp = tonumber(tostring(data.maxHp))
    local hp = tonumber(tostring(data.hp))
    self:updateHealth(data.aniSpdRate, maxHp, hp)

    self.buffStartPosX = -160 + self.nameText.width + 50
    self:updateBuffIcon(data)
end

function Lua_FightBossInfoPanel:updateHealth(speedRate, maxHp, hp)
    if maxHp == nil or maxHp <= 0 then
        maxHp = 1
    end
    if hp == nil or hp < 0 then
        hp = 0
    end

    self.healthBar:setSpeedRate(speedRate)
    self.healthBar:setMaxValue(maxHp)
    self.healthBar:setValue(hp)
end

function Lua_FightBossInfoPanel:updateBuffIcon(data)
    self:returnIcon()
    if data == nil or data.buffCount <= 0 then
        return
    end

    local count = data.buffCount - 1
    local dic = {}
    local len = 0
    local buffId
    local buffData
    local key
    for i = 0, count do
        buffId = data:getBuffIdByIdx(i)
        buffData = Lua_BuffConfigData.getConfigData(buffId)
        if buffData and not strIsNullOrEmpty(buffData.atlas) and not strIsNullOrEmpty(buffData.sprite) then
            key = buffData.main_type * 10000 + buffData.sub_type
            if dic[key] == nil then
                local vo = Lua_BuffVo.new()
                vo.atlas = buffData.atlas
                vo.sprite = buffData.sprite
                vo.sortWeight = buffData.sort
                vo.overlayNum = data:getBuffOverlayNumByIdx(i)
                dic[key] = vo
                len = len + 1
            else
                dic[key].overlayNum = dic[key].overlayNum + data:getBuffOverlayNumByIdx(i)
            end
        end
    end

    local arr = Array()
    for k,v in pairs(dic) do
        arr:add(v)
    end
    arr:sort("sortWeight", false)

    local icon
    for i = 1, len do
        if i > DataCenter.fightUtil.fightBuffShowNum then
            return;
        end
        icon = self:createIcon()
        icon:setLocation(self.buffStartPosX + (i - 1) * 40, 21, 0)
        icon:setData(arr[i])
    end
end

function Lua_FightBossInfoPanel:clearBuffIcon()
    if self.showList then
        self.showList:dispose()
        self.showList:clear()
        self.showList = nil
    end
    if self.hideList then
        self.hideList:dispose()
        self.hideList:clear()
        self.hideList = nil
    end
end

function Lua_FightBossInfoPanel:createIcon()
    if self.showList == nil then
        self.showList = Array()
    end
    if self.hideList == nil then
        self.hideList = Array()
    end

    local len = self.hideList:getSize()
    local icon = nil
    if len > 0 then
        icon = self.hideList:remove()
    end

    if icon == nil then
        icon = Lua_BuffIcon.new(self.content)
    end
    icon:setEnable(true)
    self.showList:add(icon)
    return icon
end

function Lua_FightBossInfoPanel:returnIcon()
    if self.showList == nil or self.hideList == nil then
        return
    end

    local len = self.showList:getSize()
    local icon
    while len > 0 do
        icon = self.showList:remove(len)
        icon:setEnable(false)
        self.hideList:add(icon)
        len = len - 1
    end
end