-- 战斗剧情面板
checkRequire("Lua_GuideImgDialogPanel")
checkRequire("Lua_GuideModelEffDialogPanel")
checkRequire("Lua_FightPlotBubble")
Lua_FightPlotPanel = class("Lua_FightPlotPanel")
function Lua_FightPlotPanel:ctor(parent)
	self.curFrameTime = 0;
	self.bComplete = false;
	self.plotUnitsDic = {};
	self.parent = parent;
	self.recordId = 0;
	self.plotId = 0;
	self:superCall("ctor")
end

function Lua_FightPlotPanel:dispose()
	for k, v in pairs(self.plotUnitsDic) do
		v:dispose();
        self.plotUnitsDic[k] = nil;
    end

	if self.plotArr ~= nil then -- 等待播放的剧情队列
		self.plotArr:clear();
		self.plotArr = nil;
	end

	if self.excutePlots ~= nil then -- 当前执行的剧情队列 
		local len = self.excutePlots:getSize();
		while (len > 0) do
			self.excutePlots[len]:dispose();
			self.excutePlots:remove(len);
			len = len - 1;
		end
		self.excutePlots = nil;
	end

	if self.idlePlots ~= nil then -- 闲置的剧情单元集合
		self.idlePlots:clear();
		self.idlePlots = nil;
	end

	self.fightPlayer = nil;
	self.recordId = 0;
	self.plotId = 0;
	self.config = nil;
	self:clearTimer();
	self:superCall("dispose")
end

function Lua_FightPlotPanel:clearPlotUnits()
	for k, v in pairs(self.plotUnitsDic) do
        self.plotUnitsDic[k] = nil;
        if self.idlePlots == nil then
			self.idlePlots = Array();
		end
		self.idlePlots:add(v);
    end
end

function Lua_FightPlotPanel:clearExcutePlots()
	if self.excutePlots ~= nil then
		local len = self.excutePlots:getSize();
		while (len > 0) do
			local plotItem = self.excutePlots:remove(len);
			local plotUnit = plotItem.plotUnit;
			self.plotUnitsDic[plotUnit.eventId] = nil;
			if self.idlePlots == nil then
				self.idlePlots = Array();
			end
			self.idlePlots:add(plotUnit);
			plotItem:dispose();
			len = len - 1;
		end
	end
end

function Lua_FightPlotPanel:updateServerPlot(eid)
	-- print("updateServerPlot", eid);
	if self.plotUnitsDic ~= nil and self.plotUnitsDic[eid] ~= nil then
		local plotUnit = self.plotUnitsDic[eid];
		plotUnit.bServerTrigger = true;
		if self.plotArr ~= nil then
			local idx = self.plotArr:indexOf(eid);
			if idx > 0 then
				local bOperate = true;
	    		local lastId = plotUnit.lastId;
	    		if lastId ~= nil and self.plotUnitsDic[lastId] ~= nil then
	    			bOperate = self.plotUnitsDic[lastId].bPlayEnd;
	    		end
	    		if bOperate and plotUnit:checkPlay() then -- 可播放
	    			self.plotArr:remove(idx);
					local plotItem = Lua_FightPlotItem.new(self.parent);
					if plotItem:setUnit(plotUnit) then
		    			if self.excutePlots == nil then
							self.excutePlots = Array();
						end
						self.excutePlots:add(plotItem);
						DataCenter.fightData:controllFightPlay(self.recordId, false);
					else
						-- print("updateServerPlot bPlayEnd true", eid)
						plotUnit.bPlayEnd = true;
					end
	    		end
	    	end
    	end
	end
end

function Lua_FightPlotPanel:playPlot(rid, pid, cfg)
	if self.recordId == rid and self.plotId == pid then
		return;
	end

	-- print("playPlot", rid, pid);
	self.recordId = rid;
	if self.recordId == nil or self.recordId <= 0 then
		self:clearTimer();
		self.bComplete = true;
		if self.plotArr ~= nil then self.plotArr:clear(); end
		self:clearExcutePlots();
		self:clearPlotUnits();
		return;
	end

	self.plotId = pid;
	self.config = cfg;
	if cfg == nil then
		self.config = getConfig("tb_fight_plot", pid);
	end

	self:initPlot();
	self:addTimer();
	self:frameScript(0);
end

function Lua_FightPlotPanel:initPlot()
	if self.plotArr ~= nil then self.plotArr:clear(); end
	self:clearExcutePlots();
	self:clearPlotUnits();
	if self.config == nil then
		self.bComplete = true;
		return;
	end

	local list = self.config.event_list;
	if list == nil or #list <= 0 then
		self.bComplete = true;
		return;
	end

	local plotUnit;
	self.bComplete = false;
	for i = 1, #list do
		plotUnit = nil;
		local eventId = list[i];
		if self.idlePlots ~= nil then
			plotUnit = self.idlePlots:remove();
		end
		if plotUnit == nil then
			plotUnit = Lua_FightPlotUnit.new();
		end
		plotUnit:setData(self.recordId, i, eventId);
		if self.plotUnitsDic[eventId] == nil then
			self.plotUnitsDic[eventId] = plotUnit;
			if self.plotArr == nil then self.plotArr = Array(); end
			self.plotArr:add(eventId);
		end
	end
end

function Lua_FightPlotPanel:addTimer()
	if self.config == nil or self.bComplete then
		self:clearTimer();
		return;
	end

	if not self.bAddTimer then
		self.bAddTimer = true;
		Lua_CommonUtil.addTimer("fightPlotPanel_frameScript", 0.01, self, self.frameScript);
	end
end

function Lua_FightPlotPanel:clearTimer()
	if self.bAddTimer then
		self.bAddTimer = false;
		Lua_CommonUtil.removeTimer(self, self.frameScript);
	end
end

function Lua_FightPlotPanel:frameScript(dt)
	local t = getTime();
    local dt = (t - self.curFrameTime); -- 等比加速
    self.curFrameTime = t;
  	self.bComplete = true;

  	local eventId;
  	local plotUnit;
    local plotItem;
    if self.excutePlots ~= nil then
    	local len = self.excutePlots:getSize();
    	while (len > 0) do
    		plotItem = self.excutePlots[len];
    		if plotItem:frameScript(dt) then -- 完成播放
    			plotUnit = plotItem.plotUnit;
    			eventId = plotUnit.eventId;
    			self.plotUnitsDic[eventId].bPlayEnd = true;
    			self.excutePlots:remove(len);
    			plotItem:dispose();
    		else
    			self.bComplete = false;
    		end
    		len = len - 1;
    	end
    end

    if self.plotArr ~= nil then
    	local len = self.plotArr:getSize();
    	while (len > 0) do
    		self.bComplete = false;
    		eventId = self.plotArr[len];
    		plotUnit = self.plotUnitsDic[eventId];
    		local bOperate = true;
    		local lastId = plotUnit.lastId;
    		if lastId ~= nil and self.plotUnitsDic[lastId] ~= nil then
    			bOperate = self.plotUnitsDic[lastId].bPlayEnd;
    		end
    		if bOperate and plotUnit:checkPlay() then -- 可播放
    			self.plotArr:remove(len);
				plotItem = Lua_FightPlotItem.new(self.parent);
				if plotItem:setUnit(plotUnit) then
	    			if self.excutePlots == nil then
						self.excutePlots = Array();
					end
					self.excutePlots:add(plotItem);
				else
					plotUnit.bPlayEnd = true;
					-- print("2updateServerPlot bPlayEnd true", eventId)
				end
    		end
    		len = len - 1;
    	end
    end

    DataCenter.fightData:controllFightPlay(self.recordId, not (self.excutePlots ~= nil and self.excutePlots:getSize() > 0));
    if self.bComplete then
	    self:clearTimer();
	end
end













-- 剧情播放单元
Lua_FightPlotItem = class("Lua_FightPlotItem");
function Lua_FightPlotItem:ctor(root)
	self:superCall("ctor");
	self.parent = root;
end

function Lua_FightPlotItem:dispose()
	self.parent = nil;
	self.plotUnit = nil;
	if self.templateTweenName ~= nil then
		DataCenter.winTweenManager:removeWinTween(self.templateTweenName);
	end

	if self.templatePanel ~= nil then
		self.templatePanel:dispose();
		self.templatePanel = nil;
	end

	if self.bubblePanel ~= nil then
		self.bubblePanel:dispose();
		self.bubblePanel = nil;
	end
end

function Lua_FightPlotItem:clearWidgets()
	if self.templateTweenName ~= nil then
		DataCenter.winTweenManager:removeWinTween(self.templateTweenName);
	end

	if self.templatePanel ~= nil then
		self.templatePanel:dispose();
		self.templatePanel = nil;
	end

	if self.bubblePanel ~= nil then
		self.bubblePanel:dispose();
		self.bubblePanel = nil;
	end
end

function Lua_FightPlotItem:setUnit(unit)
	self:clearWidgets();
	self.plotUnit = unit;
	local config = unit.config;

	self.intervalTime = config.time ~= nil and (config.time / 1000) or 3;
	local bShow = self:createContentTemplate(config.contentTemplate, config.contentTweenClassName);
	return self:createBubble(config) or bShow;
end

-- 创建内容模板
function Lua_FightPlotItem:createContentTemplate(templateType, contentTweenClassName)
	if self.templateTweenName ~= nil then
		DataCenter.winTweenManager:removeWinTween(self.templateTweenName);
	end

	if self.templateType == nil or self.templateType ~= templateType then
		if self.templatePanel ~= nil then
			self.templatePanel:dispose();
			self.templatePanel = nil;
		end

		self.templateType = templateType;
		if templateType == Lua_GuideDefine.GuideWin_Template_ImgDialogLeft
			or templateType == Lua_GuideDefine.GuideWin_Template_ImgDialogRight then --立绘对话左、右
			self.templatePanel = Lua_GuideImgDialogPanel.new(self.parent, templateType);
		elseif templateType == Lua_GuideDefine.GuideWin_Template_ModelEffDialogLeft 
			or templateType == Lua_GuideDefine.GuideWin_Template_ModelEffDialogRight then --模型spine对话左、右
			self.templatePanel = Lua_GuideModelEffDialogPanel.new(self.parent, templateType);
		end
	else
		self.templatePanel:setEnable(true);
	end

	if self.templatePanel ~= nil then 
		self.templatePanel:initInfo(self.plotUnit.config);
		self:setTemplatePanelPos();
		if not strIsNullOrEmpty(contentTweenClassName) then -- 界面动画
			self.templateTweenName = DataCenter.winTweenManager:createWinTween(contentTweenClassName, self.templatePanel.content.transform);
		end
		return true;
	end
	return false;
end

function Lua_FightPlotItem:setTemplatePanelPos()
	local posX, posY = 0, 720;
	local posList = self.plotUnit.config.contentTemplatePos;
	if posList ~= nil and self.templatePanel ~= nil then
		posX = posList[1] or 0;
		posY = posList[2] or 720;
	end
	self.templatePanel:setLocation(posX, posY);
end

function Lua_FightPlotItem:createBubble(cfg)
	if cfg ~= nil and cfg.bubble ~= nil and cfg.bubble ~= 0 then
		local bubbleContent = cfg.bubbleContent;
		if not strIsNullOrEmpty(bubbleContent) then
			-- 计算位置
			local rid = 0;
			local side = cfg.bubbleSide ~= nil and cfg.bubbleSide or 0;
			local bubbleTarget = cfg.bubbleTarget;
			local stand = (bubbleTarget ~= nil and bubbleTarget.stand ~= nil) and bubbleTarget.stand or -1;
			local heroId = (bubbleTarget ~= nil and bubbleTarget.heroId ~= nil) and bubbleTarget.heroId or 0;
			local fightId = self.plotUnit.fightId;
			local recordVo = DataCenter.fightData:getRecordVoById(fightId);
			if recordVo ~= nil then
				if stand >= 0 and stand <= 9 then
					rid = recordVo:getFighterByPos(side, stand);
				end

				if rid > 0 then
					if heroId ~= recordVo:getFighterInfo(rid) then
						rid = 0;
					end
				else 
					stand, rid = recordVo:getFighterByHero(side, heroId);
				end
			end

			-- print("createBubble", self.plotUnit.eventId, rid, side, heroId)
			if rid > 0 then
				local player = DataCenter.thingData:getThingPlayer(recordVo.sceneId, fightId, rid);
				if player ~= nil then
					local sx = player.player.curScreenShowPointX;
					local sy = player.player.curScreenShowPointY;
					local px = LuaUtil.getScreenPosXInverseObj(self.parent, sx, sy, 0);
					local py = LuaUtil.getScreenPosYInverseObj(self.parent, sx, sy, 0);
					if self.bubblePanel == nil then
						self.bubblePanel = Lua_FightPlotBubble.new(self.parent);
					end
					self.bubblePanel:setLocation(px, py+140, 0);
					self.bubblePanel:setContent(bubbleContent);
					-- print("createBubble succee", self.plotUnit.eventId, rid, side, heroId)
					return true;
				end
			end
		end
	end

	if self.bubblePanel ~= nil then
		self.bubblePanel:dispose();
		self.bubblePanel = nil;
	end
	return false;
end

function Lua_FightPlotItem:frameScript(dt)
	self.intervalTime = self.intervalTime - dt;
	if self.templatePanel ~= nil and self.templatePanel.frameScript ~= nil then
		self.templatePanel:frameScript(dt, dt);
	end
	return self.intervalTime <= 0;
end


















-- 战斗剧情数据单元
Lua_FightPlotUnit = class("Lua_FightPlotUnit");
function Lua_FightPlotUnit:ctor()
	self:superCall("ctor");

end

function Lua_FightPlotUnit:dispose()
	self.config = nil;

end

-- fightId 战斗id
-- idx 索引 
-- eventId 事件id
function Lua_FightPlotUnit:setData(fightId, idx, eventId)
	self.bPlayEnd = false;
	self.bServerTrigger = false;
	self._sortIdx = nil;
	self._bComplete = nil;
	self.fightId = fightId;
	self.index = idx;
	self.eventId = eventId;
	self.config = getConfig("tb_plot_event", eventId);
	if self.config == nil then
		self._bComplete = true;
	end
end

function Lua_FightPlotUnit.Get:lastId()
	if self.config == nil then
		return nil;
	end
	return self.config.lastId;
end

function Lua_FightPlotUnit.Get:round()
	if self.config == nil or self.config.round == nil then
		return 0;
	end
	return self.config.round;
end

function Lua_FightPlotUnit.Get:actionIdx()
	if self.config == nil or self.config.actionIdx == nil then
		return 0;
	end
	return self.config.actionIdx;
end

function Lua_FightPlotUnit:checkPlay()
	if self.fightId == nil or self.fightId <= 0 then
		return false;
	end

	if self.bServerTrigger then -- 服务端触发了
		self._bComplete = true;
		return true;
	end

	if self._bComplete == nil then
		local fightPlayer = DataCenter.fightData:getFightPlayerById(self.fightId);
		if fightPlayer ~= nil and fightPlayer.curActionInfo ~= nil then
			local curActionInfo = fightPlayer.curActionInfo;
			-- if curActionInfo.event_id > 0 then
			-- 	print("11 server event_id", curActionInfo.event_id, self.eventId, curActionInfo.round, fightPlayer.curAction);
			-- end
			-- if curActionInfo.event_id == self.eventId then -- 服务端触发事件
			-- 	print("server event_id", event_id, curActionInfo.round, fightPlayer.curAction)
	        --     self._bComplete = true;
            -- 	return true;
            -- end

            if self.config.server ~= 1 then
            	local round = self.round;
            	local actionIdx = self.actionIdx;
	            local curRound = curActionInfo.round; -- 回合
	            local curAction = fightPlayer.curAction; -- 行动
	            local recordVo = DataCenter.fightData:getRecordVoById(self.fightId);
				-- print("checkPlay", self.eventId, "round", round, "actionIdx", actionIdx, "curRound", curRound, "curAction", curAction);
	            if round == 0 then -- 任意回合
	            	if actionIdx == -1 then -- 回合最后一次行动
	            		local maxAct = recordVo:getMaxActionByRound(fightPlayer.curRotation, fightPlayer.curSession, curRound);
	            		if curAction < maxAct then
	            			return false;
	            		end
	            	elseif actionIdx > 0 and actionIdx ~= curAction then
	            		return false;
	            	end
	           	elseif round == -1 then -- 战斗结束
	           		if not fightPlayer.isPlayEnd then
	           			return false;
	           		end
	           	elseif round == curRound then -- 指定回合
	           		if actionIdx == -1 then -- 回合最后一次行动
	           			local maxAct = recordVo:getMaxActionByRound(fightPlayer.curRotation, fightPlayer.curSession, curRound);
	            		if curAction < maxAct then
	            			return false;
	            		end
	           		elseif actionIdx > 0 and actionIdx ~= curAction then
	           			return false;
	           		end
	           	else
	           		return false;
	           	end

	            -- 事件配置表条件
	            local trigger_conditions = self.config.trigger_conditions;
	            if trigger_conditions ~= nil and #trigger_conditions > 0 then
	            	for i = 1, #trigger_conditions do
	            		local info = trigger_conditions[i];
	            		if info ~= nil and #info > 0 then
	            			if info[1] == Lua_FightDefine.PLOT_CONDITION_HERO then -- 英雄
	            				local side = #info > 1 and info[2] or 0;
	            				local heroId = #info > 2 and info[3] or 0;
	            				if heroId > 0 then
	            					local stand, rid = recordVo:getFighterByHero(side, heroId);
	            					-- print("getFighterByHero rid", rid);
	            					if rid <= 0 or DataCenter.thingData:getThingPlayer(recordVo.sceneId, self.fightId, rid) == nil then
	            						return false;
	            					end
	            				end
	            			end
	            		end
	            	end
	            end

	            -- 都成立
	            self._bComplete = true;
	        end
		end
	end
	return self._bComplete;
end