-- 组队
Lua_FightTeamUpPanel = class("Lua_FightTeamUpPanel", Lua_DisplayObject);
function Lua_FightTeamUpPanel:ctor(p)
	self:superCall("ctor", p, "FightTeamUpPanel_skin");
end

function Lua_FightTeamUpPanel:buildShowItem()
	self:superCall("buildShowItem");
	-- self:addLuaEvent("FIGHT_HELP_UPDATE", self, self.updateShowInfo);
	self.showState = true;
	self.showArr = Array();

	self.showObject:SetActive(self.showState);
	self.openBtn:addClickFuntion(self, self.onOpenClick);
end

function Lua_FightTeamUpPanel:dispose()
	Lua_CommonUtil.removeTimer(self, self.onAutoHide);
	if self.showArr then
		local len = self.showArr:getSize();
		local item;
		while len > 0 do
			item = self.showArr:remove(len);
			if item then
				item:dispose();
			end
			len = len - 1;
		end
	end
	self.recordId = nil;
	self:superCall("dispose");
end

function Lua_FightTeamUpPanel:setData(recordId)
	self.recordId = recordId;
	self:updateShowInfo();
end

function Lua_FightTeamUpPanel:updateShowInfo()
	local recordVo = DataCenter.fightData:getRecordVoById(self.recordId);
	if recordVo then
		if recordVo.isAssist then
			self.promptIcon:setEnable(true);
			self.promptIcon:setAltas("equipcopy_atlas_1", "xui_jmd_widget_68");
		elseif recordVo.ownType == -1 then
			self.promptIcon:setEnable(true);
			self.promptIcon:setAltas("equipcopy_atlas_1", "xui_jmd_widget_44");
		else
			self.promptIcon:setEnable(false);
		end
	else
		self.promptIcon:setEnable(false);
	end

	local len = self.showArr:getSize();
	for i = 1, len do
		self.showArr[i]:setEnable(false);
	end
	
	local arr = DataCenter.fightData:getGroupArrById(recordVo.groupId);
	if arr == nil then
		return;
	end

	local player;
	local index = 0;
	local item;
	for i = 1, arr:getSize() do
		if arr[i] ~= self.recordId then
			player = DataCenter.fightData:getFightPlayerById(arr[i]);
			if player ~= nil then
				index = index + 1;
				item = self.showArr[index];
				if item == nil then
					item = Lua_FightTeamItem.new(self.showObject);
					self.showArr:add(item);
				else
					item:setEnable(true);
				end
				item:setLocation(-175, -82 + (index - 1) * -104, 0);
				item:setData(arr[i]);
			end
		end
	end
	if index > 0 then
		self.infoBg:SetDimensions(250, 8 + index * 100 + (index - 1) * 3);
	else
		self.infoBg:SetDimensions(250, 0);
	end
end

function Lua_FightTeamUpPanel:setShowHide(value)
	self.showState = value;
	self:updateShowHide();
end

function Lua_FightTeamUpPanel:setAutoHide(value)
	value = value or 0
	Lua_CommonUtil.delayCall(value, self, self.onAutoHide)
end

function Lua_FightTeamUpPanel:onAutoHide()
	self:setShowHide(false)
end

function Lua_FightTeamUpPanel:onOpenClick()
	self.showState = not self.showState;
	self:updateShowHide();
end

function Lua_FightTeamUpPanel:updateShowHide()
	if self.showState then
		self.openBtn:setAltas("fight_atlas_1", "xui_xhd_button_004_n")
	else
		self.openBtn:setAltas("fight_atlas_1", "xui_xhd_button_003_n")
	end
	self.showObject:SetActive(self.showState)
end










Lua_FightTeamItem = class("Lua_FightTeamItem", Lua_DisplayObject);
function Lua_FightTeamItem:ctor(p)
	self:superCall("ctor", p, "FightTeamItem_skin");
end

function Lua_FightTeamItem:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("FIGHTPLAY_CHECK_UPDATE", self, self.updateData);

	self.attackerAvatar = Lua_AvatarItem.new(self.content);
	self.attackerAvatar:setRoleAvatar(0);
	self.attackerAvatar:setRoleFrame(0);
	self.attackerAvatar:setScale(0.55, 0.55, 1);
	self.attackerAvatar:setLocation(-80, 0, 0);

	self.bossAvatar = Lua_AvatarItem.new(self.content);
	self.bossAvatar:setRoleAvatar(0);
	self.bossAvatar:setRoleFrame(0);
	self.bossAvatar:setSiblingIndex(3);
	self.bossAvatar:setLocation(74, 1, 0);
	self.bossAvatar:setScale(0.55, 0.55, 1);

	self.promptText:setLangValue(420123);
	self.bg.clickScale = false;
	self.bg:addClickFuntion(self, self.onClick);
end

function Lua_FightTeamItem:setData(recordId)
	self.recordId = recordId;

	self.recordVo = DataCenter.fightData:getRecordVoById(recordId);
	self.promptText:setEnable(self.recordVo.isAssist);

	local attacker = self.recordVo.attacker;
	self.attackerAvatar:setRoleDressUp(attacker.dress_info);
	-- self.attackerAvatar:setRoleName(attacker.name); -- 2023/5/25 策划需求屏蔽

	local arr = self.recordVo:getFighterArr(Lua_FightDefine.FIGHT_DEFENDER, 2);
	if arr ~= nil and arr:getSize() > 0 then
		local boosId = self.recordVo:getFighterInfo(arr[1]);
		local config = Lua_MonsterConfigData.getMonsterConfig(boosId);
		if config ~= nil and config.heroVo ~= nil then
			self.bossAvatar:setAvatar(config.heroVo.avatar_atlas_1, config.heroVo.avatar_sprite_1, 0.9);
		end
		self.campIcon:setAltas("common_altas_2", "xui_common_attribute_"..config.heroVo.campType);
	end

	self:updateData(recordId);
end

function Lua_FightTeamItem:updateData(recordId)
	if self.recordId ~= recordId then
		return;
	end

	local maxHp = self.recordVo.attackerMaxHp;
	local hp = self.recordVo.attackerHp;
	maxHp = maxHp == nil and 1 or maxHp;
	hp = hp == nil and 1 or hp;
	self.attackerBar:setMaxValue(maxHp);
	self.attackerBar:setValue(hp);

	maxHp = self.recordVo.defenderMaxHp;
	hp = self.recordVo.defenderHp;
	maxHp = maxHp == nil and 1 or maxHp;
	hp = hp == nil and 1 or hp;
	self.bossBar:setMaxValue(maxHp);
	self.bossBar:setValue(hp);
end

function Lua_FightTeamItem:onClick(go)
	local player = DataCenter.fightData:getFightPlayerById(self.recordId);
	if player ~= nil and player.isPlayEnd == true then
		OperateAlert.showLangValue(420091);
		return;
	end
	DataCenter.fightData:showFightToStageByRid(self.recordId);
end

function Lua_FightTeamItem:dispose()
	if self.attackerAvatar ~= nil then
		self.attackerAvatar:dispose();
		self.attackerAvatar = nil;
	end
	if self.bossAvatar ~= nil then
		self.bossAvatar:dispose();
		self.bossAvatar = nil;
	end
	self.recordId = nil;
	self.recordVo = nil;
	self:superCall("dispose");
end