checkRequire("Lua_FightResultBaseWindow");
Lua_ArenaFightFailWindow = class("Lua_ArenaFightFailWindow", Lua_FightResultBaseWindow);
function Lua_ArenaFightFailWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ArenaFightFailWindow";
	self.skinName = "ArenaFightResultWindow_skin";
	self.winBgPath = "/images/fight/xui_zd_bg_2.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/effects/uiEffects/ui_zdjs_sb_01", Lua_LoadFileType.UNITY3D);
	self.openSound = "fight_lose_01";

	self.bIsWin = false;
	self.bIsShowCountTime = true;
	self.bIsShowHurtBtn = true;
end

function Lua_ArenaFightFailWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.nameBg:setAltas("fight_atlas_3", "xui_zd_widget_20");
	self.bg:setAltas("fight_atlas_3", "xui_zd_widget_19");
	self.rewardTitle:setAltas("fight_atlas_2", "xui_zd_word_4");

	self.selfAvatar = Lua_AvatarItem.new(self.content);
	self.selfAvatar:setScale(0.8, 0.8, 1);
	self.selfAvatar:setLocation(-145, -93, 0);

	self.opponentAvatar = Lua_AvatarItem.new(self.content);
	self.opponentAvatar:setScale(0.8, 0.8, 1);
	self.opponentAvatar:setLocation(145, -93, 0);
	
	self.btnBack:addClickFuntion(self, self.onBtnBackClick);
	self.btnSure:addClickFuntion(self, self.hide);
end

function Lua_ArenaFightFailWindow:dispose()
	if self.selfAvatar ~= nil then
		self.selfAvatar:dispose();
		self.selfAvatar = nil;
	end
	if self.opponentAvatar ~= nil then
		self.opponentAvatar:dispose();
		self.opponentAvatar = nil;
	end
	self:clearRewardsList();
	self:superCall("dispose");
end

function Lua_ArenaFightFailWindow:showWin(param)
	self:superCall("showWin", param);
	local templateConfig = Lua_FightTemplateConfigData.getConfigData(param.template_id);
	self.nameText.text = templateConfig.title;
	if Lua_WindowUtil.isWindowShowing("Lua_ArenaWindow") or DataCenter.funcPathUtil:haveFightRecordFuncPath(param.record_id) then
		self.btnBack:setEnable(false);
		self.btnSure:setLocation(0, -536, 0);
	else
		self.btnBack:setEnable(true);
		self.btnSure:setLocation(169, -536, 0);
	end
	self:updateShowInfo();
	self:updateRewards(param.item_list);
end

function Lua_ArenaFightFailWindow:updateShowInfo()
	self.selfName.text = self.showData.arena_self_info.name;
	self.selfIntegral.text = self.showData.arena_self_info.score;
	local score_change = self.showData.arena_self_info.score_change;
	if score_change == 0 then
		self.sprIntegral_1:setLocation(-176, -165, 0);
		self.selfIntegral:setLocation(-161, -165, 0);
		self.selfArrow:setEnable(false);
		self.selfChange:setEnable(false);
	else
		self.sprIntegral_1:setLocation(-217, -165, 0);
		self.selfIntegral:setLocation(-202, -165, 0);
		self.selfArrow:setEnable(true);
		self.selfChange:setEnable(true);
		if score_change > 0 then
			self.selfArrow:setAltas("fight_atlas_2", "xui_zd_label_01");
			self.selfChange.colorStr = Lua_ColorDefine.transColorStr("65BE7E");
		else
			self.selfArrow:setAltas("fight_atlas_2", "xui_zd_label_02");
			self.selfChange.colorStr = Lua_ColorDefine.transColorStr("EE917F");
		end
		self.selfChange.text = score_change;
	end
	self.selfAvatar:setRoleAvatar(self.showData.arena_self_info.head_id);
	self.selfAvatar:setRoleLevel(self.showData.arena_self_info.level);

	self.opponentName.text = self.showData.arena_fighter_info.name;
	self.opponentIntegral.text = self.showData.arena_fighter_info.score;
	score_change = self.showData.arena_fighter_info.score_change;
	if score_change == 0 then
		self.sprIntegral_2:setLocation(112, -165, 0);
		self.opponentIntegral:setLocation(127, -165, 0);
		self.opponentArrow:setEnable(false);
		self.opponentChange:setEnable(false);
	else
		self.sprIntegral_2:setLocation(71, -165, 0);
		self.opponentIntegral:setLocation(86, -165, 0);
		self.opponentArrow:setEnable(true);
		self.opponentChange:setEnable(true);
		if score_change > 0 then
			self.opponentArrow:setAltas("fight_atlas_2", "xui_zd_label_01");
			self.opponentChange.colorStr = Lua_ColorDefine.transColorStr("65BE7E");
		else
			self.opponentArrow:setAltas("fight_atlas_2", "xui_zd_label_02");
			self.opponentChange.colorStr = Lua_ColorDefine.transColorStr("EE917F");
		end
		self.opponentChange.text = score_change;
	end
	self.opponentAvatar:setRoleAvatar(self.showData.arena_fighter_info.head_id);
	self.opponentAvatar:setRoleLevel(self.showData.arena_fighter_info.level);
end

function Lua_ArenaFightFailWindow:updateRewards(itemList)
	if itemList == nil or #itemList <= 0 then
		self:clearRewardList();
		return;
	end

	local tab = DataCenter.packData:getRewardDic(itemList);
	local arr = DataCenter.packData:getRewardList(tab);
	if self.rewardList == nil then
		local len = arr:getSize();
		if len > 4 then
			self.rewardBg:SetDimensions(720, 266);
			self.rewardList = Lua_DragList.new(self.content, 556, 240, Lua_AxisDefine.Vertical);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4);
		else
			self.rewardBg:SetDimensions(720, 176);
			self.rewardList = Lua_DragList.new(self.content, len * 124 + (len - 1) * 20, 160, Lua_AxisDefine.Vertical);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4);
		end
		self.rewardList:setCellSpacing(20, 0);
		-- self.rewardList:setRectAnchor(7);
		self.rewardList:setRectPivot(1)
		self.rewardList:setLocation(0, -299, 0);
	end
	self.rewardList:setArrayData(arr);
	self.rewardList.canDrag = not self.rewardList.isTheEnd;
end

function Lua_ArenaFightFailWindow:clearRewardsList()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
end

function Lua_ArenaFightFailWindow:onBtnBackClick(go)
	DataCenter.funcPathUtil:gotoFunction(1013, true, false)
end