checkRequire("Lua_FightResultBaseWindow");
Lua_ChaosCopyFightWinResultWindow = class("Lua_ChaosCopyFightWinResultWindow", Lua_FightResultBaseWindow)
function Lua_ChaosCopyFightWinResultWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ChaosCopyFightWinResultWindow";
	self.skinName = "ChaosCopyFightResultWindow_skin";
	self.winBgPath = "/images/fight/xui_zd_bg_1.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/effects/uiEffects/ui_zdjs_sl_01", Lua_LoadFileType.UNITY3D);
	self.openSound = "fight_win_01";

	self.bIsWin = true;
	self.bIsShowHurtBtn = true;
end

function Lua_ChaosCopyFightWinResultWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.changeList = Array();

	self.heroList_1 = Lua_DragList.new(self.showObject_2, 570, 125, Lua_AxisDefine.Horizontal);
	self.heroList_1:setRectAnchor(7);
	self.heroList_1:setLocation(0, 475, 0);
	self.heroList_1:setListCell(Lua_ChaosCopyFightResultHeroItem, 110, 125, 1);

	self.heroList_2 = Lua_DragList.new(self.showObject_2, 570, 125, Lua_AxisDefine.Horizontal);
	self.heroList_2:setRectAnchor(7);
	self.heroList_2:setLocation(0, 332, 0);
	self.heroList_2:setListCell(Lua_ChaosCopyFightResultHeroItem, 110, 125, 1);

	self.btnBack:addClickFuntion(self, self.onBackClick);
	self.btnSure:addClickFuntion(self, self.onSureClick);
end

function Lua_ChaosCopyFightWinResultWindow:dispose()
	Lua_CommonUtil.removeTimer(self, self.hide);
	if self.changeList then
		self.changeList:dispose();
		self.changeList:clear();
		self.changeList = nil;
	end
	if self.heroList_1 then
		self.heroList_1:dispose();
		self.heroList_1 = nil;
	end
	if self.heroList_2 then
		self.heroList_2:dispose();
		self.heroList_2 = nil;
	end
	self:clearRewardList();
	
	if DataCenter.chaosCopyData.msg80243011 ~= nil then
		Lua_WindowUtil.openWin("Lua_ChaosCopyChapterRewardWindow", Lua_WinParam.ACTION_OPEN);
	end

	self:superCall("dispose");
end

function Lua_ChaosCopyFightWinResultWindow:showWin(param)
	self:superCall("showWin", param);

	local config = DataCenter.chaosCopyUtil:getStageConfig(param.stage_id);
	if param.result == 1 and config and config.next_id > 0 and config.is_camp_limit ~= 1 and (config.pass_chapter_reward == nil or #config.pass_chapter_reward <= 0) then
		self.bAutoNextFight = true;
		self.nextStageId = config.next_id;
		self.btnSure:setLangValue(796041);
	else
		self.bAutoNextFight = false;
		self.nextStageId = 0;
		self.btnSure:setLangValue(796043);
	end
	self:updateChange(param.stage_id);

	local fightInfo = param.fight_info;
	for i = 1, #fightInfo do
		self.recordId = tonumber(fightInfo[i].record_id)
		if DataCenter.funcPathUtil:haveFightRecordFuncPath(self.recordId) then
			break;
		end
	end
	DataCenter.fightData.curShowResultRecordId = self.recordId;
	self:updateFightInfo(fightInfo);

	if param.result == 1 then
		self:updateRewards(param.item_list);
	else
		self:updateConds(param.star_cond);
	end

	self.bIsShowCountTime = true;
	self:initCountTime();
end

function Lua_ChaosCopyFightWinResultWindow:onRemove()
	self:stopTimer();
	DataCenter.popupWinManager:removeDataByName(self.windowName);
	local fightInfo = self.showData.fight_info;
	for i = 1, #fightInfo do
		DataCenter.fightData:removeFightResult(fightInfo[i].record_id);
 		DataCenter.fightData:removeFight(fightInfo[i].record_id);
	end
end

function Lua_ChaosCopyFightWinResultWindow:updateChange(stageId)
	for i = 1, self.changeList:getSize() do
		self.changeList[i]:setEnable(false);
	end

	if DataCenter.chaosCopyUtil:checkHookIncomeIsChange(stageId) then
		local config = DataCenter.chaosCopyUtil:getStageConfig(stageId);
		local lastCfg = DataCenter.chaosCopyUtil:getStageConfig(config.last_id);
		local item;
		for i,v in ipairs(lastCfg.hook_reward) do
			item = self.changeList[i];
			if item == nil then
				item = Lua_ChaosCopyHookIncomeChangeItem.new(self.content);
				self.changeList:add(item);
			else
				item:setEnable(true);
			end
			item:setRectAnchor(7);
			item:setLocation(0, 840 - (i - 1) * 50, 0);
			item:setData(v, config.hook_reward[i]);
		end
	end
end

function Lua_ChaosCopyFightWinResultWindow:updateFightInfo(fightInfo)
	self.heroList_1:setArrayData(fightInfo[1].hurt_collect.hurt_collect_list[1].attacker_hurt_collect);
	if fightInfo[1].result == 1 then
		self.result_1:setAltas("fight_atlas_3", "xui_kxsd_label_5");
	else
		self.result_1:setAltas("fight_atlas_3", "xui_kxsd_label_4");
	end

	if #fightInfo > 1 then
		self.rewardBg:SetDimensions(720, 295);
		table.sort(fightInfo, function(a, b) return a.index < b.index end);

		self.heroList_1:setLocation(0, 475, 0);
		self.team_1:setLocation(-318, 475, 0);
		self.result_1:setLocation(317, 475, 0);
		
		self.heroList_2:setEnable(true);
		self.heroList_2:setArrayData(fightInfo[2].hurt_collect.hurt_collect_list[1].attacker_hurt_collect);

		self.team_2:setEnable(true);
		self.result_2:setEnable(true);
		if fightInfo[2].result == 1 then
			self.result_2:setAltas("fight_atlas_3", "xui_kxsd_label_5");
		else
			self.result_2:setAltas("fight_atlas_3", "xui_kxsd_label_4");
		end
	else
		self.rewardBg:SetDimensions(720, 180);

		self.heroList_1:setLocation(0, 404, 0);
		self.team_1:setLocation(-318, 404, 0);
		self.result_1:setLocation(317, 404, 0);

		self.heroList_2:setEnable(false);
		self.team_2:setEnable(false);
		self.result_2:setEnable(false);
	end
end

function Lua_ChaosCopyFightWinResultWindow:updateRewards(itemList)
	if itemList == nil or #itemList <= 0 then
		self:clearRewardList();
		return;
	end

	if self.rewardList == nil then
		self.rewardList = Lua_DragList.new(self.showObject_2, 556, 200, Lua_AxisDefine.Vertical);
		self.rewardList:setRectAnchor(7);
		self.rewardList:setLocation(0, 656, 0);
		self.rewardList:setListCell(Lua_ChaosCopyFightResultRewardItem, 124, 200, 4);
		self.rewardList:setCellSpacing(20, 0);
		self.rewardList.tweenId = 2007;
	end
	self.rewardList:setArrayData(itemList);
	self.rewardList.canDrag = not self.rewardList.isTheEnd;
end

function Lua_ChaosCopyFightWinResultWindow:clearRewardList()
	if self.rewardList then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
end

function Lua_ChaosCopyFightWinResultWindow:updateConds(condList)

end

function Lua_ChaosCopyFightWinResultWindow:onBtnHurtClick(go)
	if self.showData == nil then
		return;
	end
	self:onCancelTimer();
	Lua_WindowUtil.openWin("Lua_KunXuHolyLandHurtWindow", Lua_WinParam.ACTION_OPEN, self.showData.fight_info);
end

function Lua_ChaosCopyFightWinResultWindow:onBackClick(go)
	if Lua_WindowUtil.isWindowShowing("Lua_ChaosCopyWindow") then
		self:hide();
	else
		if DataCenter.chaosCopyData.msg80243011 ~= nil then
			DataCenter.funcPathUtil:gotoFunction(1195, true, false, "Lua_ChaosCopyChapterRewardWindow");
		else
			DataCenter.funcPathUtil:gotoFunction(1195, true, false);
		end
	end
end

function Lua_ChaosCopyFightWinResultWindow:onSureClick(go)
	if self.clickTime and getTime() - self.clickTime < 1 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();

	if self.nextStageId > 0 then
		self:onAutoFight();
	else
		self:hide();
	end
end

function Lua_ChaosCopyFightWinResultWindow:onAutoFight()
	DataCenter.funcPathUtil:clearFightRecordFuncPath(self.recordId);
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sStartFight(self.showData.template_id, self.nextStageId);
	if Lua_WindowUtil.isWindowShowing("Lua_ChaosCopyWindow") then
		Lua_CommonUtil.delayCall(5, self, self.hide); -- 容错处理
	else
		self:hide();
	end
end










Lua_ChaosCopyHookIncomeChangeItem = class("Lua_ChaosCopyHookIncomeChangeItem", Lua_DisplayObject)
function Lua_ChaosCopyHookIncomeChangeItem:ctor(p)
	self:superCall("ctor", p, "ChaosCopyHookIncomeChangeItem_skin");
end

function Lua_ChaosCopyHookIncomeChangeItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_ChaosCopyHookIncomeChangeItem:dispose()
	self:superCall("dispose");
end

function Lua_ChaosCopyHookIncomeChangeItem:setData(curData, nextData)
	local config = getConfig("item", curData[1]);
	self.icon_1:setAltas(config.atlas, config.sprite);
	self.icon_1:SetDimensions(35, 35);
	self.icon_2:setAltas(config.atlas, config.sprite);
	self.icon_2:SetDimensions(35, 35);

	self.curValue.text = LanUtil.formateStr(796044, tostring(curData[2]));
	self.nextValue.text = LanUtil.formateStr(796044, tostring(nextData[2]));
end










Lua_ChaosCopyFightResultRewardItem = class("Lua_ChaosCopyFightResultRewardItem", Lua_ListCell)
function Lua_ChaosCopyFightResultRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.86, 0.86, 1);

	self.nameText = UICreate.createLabel(self.content, nil, 0, -78, 124, 31, 24);
	self.nameText.alignmentValue = 4;
	self.nameText.horizontalOverflowValue = 1;
	self.nameText.verticalOverflowValue = 0;
	self.nameText.colorStr = Lua_ColorDefine.transColorStr("F4F0ED");
end

function Lua_ChaosCopyFightResultRewardItem:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.scrollText then
		self.scrollText:dispose();
		self.scrollText = nil;
	end
	self.nameText = nil;
	self:superCall("dispose");
end

function Lua_ChaosCopyFightResultRewardItem:setData(data)
	local tvo = Lua_ToolVo.createToolVo(data.id);
	tvo:fromServer(data);

	self.itemIcon:setData(tvo);
	self.nameText.text = tvo.name;
	self.nameText:resetSize();
	if self.nameText.width > 124 then
		self.nameText:setEnable(false);
	if self.scrollText == nil then
		self.scrollText = Lua_ScrollText.new(self.content, Lua_AxisDefine.Horizontal, 124, 24);
		self.scrollText:setLocation(0, -78, 0);
		self.scrollText:setTextStyle(124, 24, Lua_MyUISettings.defaultFontName, 24, "F4F0ED", 0);
	end
		self.scrollText:setEnable(true);
		self.scrollText:setShowTxt(tvo.name);
	else
		self.nameText:setEnable(true);
		if self.scrollText then
			self.scrollText:setEnable(false);
		end
	end

	if data.flag == 1 then
		if self.typeIcon == nil then
			self.typeIcon = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 78, 0, 0);
		end
		self.typeIcon:setEnable(true);
		self.typeIcon:setAltas("chaos_copy_atlas", "xui_hdxj_label_06");
	else
		if self.typeIcon then
			self.typeIcon:setEnable(false);
		end
	end
end

function Lua_ChaosCopyFightResultRewardItem:onPressClick()
	self.itemIcon:onItemClick();
	Lua_MsgUtil.callFunc("FightResultWin_Timer_Stop");
end










Lua_ChaosCopyFightResultHeroItem = class("Lua_ChaosCopyFightResultHeroItem", Lua_ListCell)
function Lua_ChaosCopyFightResultHeroItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ChaosCopyFightResultHeroItem:buildShowItem()
	self:superCall("buildShowItem");

	self.heroItem = Lua_ItemIcon.new(self.content);
	self.heroItem:setLocation(0, 6, 0);
	self.heroItem:setScale(0.86, 0.86, 1);

	self.hpBar = UICreate.createProgressBar(self.content, "common_altas_1", "xui_common_tipsprogress_002_b", "common_altas_1", "xui_common_tipsprogress_002_f", 0, 0, 105, 10);
	self.hpBar:setLocation(0, -57, 0);
	self.hpBar:setScale(0.9, 0.9, 1);
	self.hpBar:setMaxValue(1);
	self.hpBar:setValue(0);
end

function Lua_ChaosCopyFightResultHeroItem:dispose()
	if self.heroItem then
		self.heroItem:dispose();
		self.heroItem = nil;
	end
	if self.hpBar then
		self.hpBar:dispose();
		self.hpBar = nil;
	end
	if self.deathIcon then
		self.deathIcon:dispose();
		self.deathIcon = nil;
	end
	self:superCall("dispose");
end

function Lua_ChaosCopyFightResultHeroItem:setData(data)
	local heroVo = Lua_HeroVo.new(data.sort_id);
	heroVo.level = data.level;
	heroVo.quality = data.quality;
	heroVo.quality_star = data.quality_star;
	heroVo.clothesId = data.clothes_id;

	self.heroItem:setData(heroVo);
	self.hpBar:setMaxValue(data.max_health);
	self.hpBar:setValue(data.health);

	if data.health <= 0 then
		self.heroItem:setGray(true);
		if self.deathIcon == nil then
			self.deathIcon = UICreate.createUIAtlasImage(self.content, "kunxuholyland_altas", "xui_kxsd_label_6", 0, 0, 0, 0);
		end
		self.deathIcon:setEnable(true);
	else
		self.heroItem:setGray(false);
		if self.deathIcon then
			self.deathIcon:setEnable(false);
		end
	end
end