checkRequire("Lua_FightResultBaseWindow");
Lua_ChaosForestFightWinWindow = class("Lua_ChaosForestFightWinWindow", Lua_FightResultBaseWindow)
function Lua_ChaosForestFightWinWindow:ctor()
	self:superCall("ctor");
	self.windowName = "Lua_ChaosForestFightWinWindow";
	self.skinName = "ChaosForestFightWinWindow_skin";
	self.openSound = "fight_win_01";
	self.winBgPath = "/images/fight/xui_zd_bg_1.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/effects/uiEffects/ui_zdjs_sl_01", Lua_LoadFileType.UNITY3D);
	
	self.bIsWin = true;
	self.bIsShowCountTime = true;
	self.bIsShowHurtBtn = true;
end

function Lua_ChaosForestFightWinWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.btnBack:addClickFuntion(self, self.onBtnBackClick);
	self.btnSure:addClickFuntion(self, self.hide);
end

function Lua_ChaosForestFightWinWindow:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self:clearRewardList();
	self:superCall("dispose");
end

function Lua_ChaosForestFightWinWindow:showWin(param)
	self:superCall("showWin", param);

	local templateConfig = Lua_FightTemplateConfigData.getConfigData(param.template_id);
	self.nameText.text = templateConfig.title;

	if Lua_WindowUtil.isWindowShowing("Lua_ChaosForestWindow") or DataCenter.funcPathUtil:haveFightRecordFuncPath(param.record_id) then
		self.btnBack:setEnable(false);
		self.btnSure:setLocation(0, -536, 0);
	else
		self.btnBack:setEnable(true);
		self.btnSure:setLocation(169, -536, 0);
	end

	if param.is_new_hurt == 1 then
		self.hurtTitle:setAltas("fight_atlas_2", "xui_zd_word_11");
	else
		self.hurtTitle:setAltas("fight_atlas_2", "xui_zd_word_10");
	end

	self:updateShowInfo();
end

function Lua_ChaosForestFightWinWindow:updateShowInfo()
	local hurt = self.showData.hurt_collect;
	local list = hurt.hurt_collect_list;
	if list == nil then
		return;
	end

	local idx = -1;
	local maxRot = -1;
	for i = 1, #list do
		if list[i].rotation > maxRot then
			maxRot = list[i].rotation;
			idx = i;
		end
	end

	local attackList = list[idx].attacker_hurt_collect;
	local defendList = list[idx].defender_hurt_collect;

	-- local mvpHeroId = self:getMvpHeroId(attackList);
	local bossHurt = self:getBossHurt(defendList);

	local index, maxHurt, prevHurt, isFinally = DataCenter.chaosForestUtil:getMaxHurt(bossHurt);
	self.stepText.text = "x"..index;
	self.hurtBar:setMaxValue(maxHurt);
	self.hurtBar:setValue(bossHurt);
	self.hurtBar:setText(bossHurt.."/"..maxHurt);

	local high_hurt = DataCenter.chaosForestData.high_hurt;
	bossHurt = (high_hurt > bossHurt) and high_hurt or bossHurt;
	self:showRewards(bossHurt);
end

-- function Lua_ChaosForestFightWinWindow:getMvpHeroId(list)
-- 	local mvpHeroId;
-- 	if list ~= nil then
-- 		local obj;
-- 		local num;
-- 		local maxIdx;
-- 		local maxHurt = -1;
-- 		for i = 1, #list do
-- 			obj = list[i];
-- 			num = Mathf.Abs(tonumber(obj.hurt)) + Mathf.Abs(tonumber(obj.cure)) + Mathf.Abs(tonumber(obj.bear_hurt));
-- 			if maxHurt < num then
-- 				maxHurt = num;
-- 				maxIdx = i;
-- 			end
-- 		end
-- 		mvpHeroId = list[maxIdx].sort_id;
-- 	end
-- 	return mvpHeroId;
-- end

function Lua_ChaosForestFightWinWindow:getBossHurt(list)
	if list ~= nil then
		for i = 1, #list do
			if list[i].type == 5 then
				return tonumber(list[i].bear_hurt);
			end
		end
	end
	return 0;
end

function Lua_ChaosForestFightWinWindow:showRewards(bossHurt)
	local list = self.showData.item_list;
	if list == nil or #list <= 0 then
		-- 预览奖励
		local arr = DataCenter.chaosForestUtil:getHurtRewardArr();
		local config;
		local targetHurt;
		for i = 1, arr:getSize() do
			config = DataCenter.chaosForestUtil:getHurtRewardInfo(arr[i]);
			if bossHurt < config.hurt then
				targetHurt = config.hurt;
				list = config.reward;
				break;
			end
		end

		if list == nil or #list <= 0 then
			self.hurtText.pivotValue = 4;
			self.hurtText.alignmentValue = 4;
			self.hurtText:setLocation(0, -299.5, 0);
			self.hurtText.text = LanUtil.formateStr(340027, tostring(bossHurt));

			self.rewardText.pivotValue = 4;
			self.rewardText.alignmentValue = 4;
			self.rewardText:setLocation(-31, -350, 0);
			self.rewardText:setLangValue(340029);
		else
			self.hurtText.pivotValue = 3;
			self.hurtText.alignmentValue = 3;
			self.hurtText:setLocation(-101, -299.5, 0);
			self.hurtText.text = LanUtil.formateStr(340027, tostring(bossHurt));

			self.rewardText.pivotValue = 3;
			self.rewardText.alignmentValue = 3;
			self.rewardText:setLocation(-101, -350, 0);
			self.rewardText.text = LanUtil.formateStr(340028, tostring(targetHurt));

			if self.itemIcon == nil then
				self.itemIcon = Lua_ItemIcon.new(self.content);
				self.itemIcon:setLocation(-181, -324, 0);
				self.itemIcon:setCanClick(true);
				
				local tvo = Lua_ToolVo.createToolVo(list[1][1], list[1][2]);
				self.itemIcon:setData(tvo);
			end
		end
	else
		self.hurtText.text = nil;
		self.rewardText.text = nil;
		self:updateRewards(list);
	end
end

function Lua_ChaosForestFightWinWindow:updateRewards(itemList)
	if itemList == nil or #itemList <= 0 then
		self.rewardBg:setEnable(false);
		self:clearRewardList();
		return;
	end

	self.rewardBg:setEnable(true);
	local tab = DataCenter.packData:getRewardDic(itemList);
	local arr = DataCenter.packData:getRewardList(tab);
	if self.rewardList == nil then
		local len = arr:getSize();
		if len > 4 then
			self.rewardBg:SetDimensions(720, 220);
			self.rewardList = Lua_DragList.new(self.content, 556, 196, Lua_AxisDefine.Vertical);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4);
		else
			self.rewardBg:SetDimensions(720, 176);
			self.rewardList = Lua_DragList.new(self.content, len * 124 + (len - 1) * 20, 160, Lua_AxisDefine.Vertical);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4);
		end
		self.rewardList:setCellSpacing(20, 0);
		-- self.rewardList:setRectAnchor(7);
		self.rewardList:setRectPivot(1)
		self.rewardList:setLocation(0, -267, 0);
	end
	self.rewardList:setArrayData(arr);
	self.rewardList.canDrag = not self.rewardList.isTheEnd;
end

function Lua_ChaosForestFightWinWindow:clearRewardList()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
end

function Lua_ChaosForestFightWinWindow:onBtnBackClick(go)
	DataCenter.funcPathUtil:gotoFunction(1036, true, false);
end