checkRequire("Lua_FightResultBaseWindow");
Lua_ClimbTowerFightWinWindow = class("Lua_ClimbTowerFightWinWindow", Lua_FightResultBaseWindow);
function Lua_ClimbTowerFightWinWindow:ctor()
	self:superCall("ctor");
	self.windowName = "Lua_ClimbTowerFightWinWindow";
	self.skinName = "ClimbTowerFightWinWindow_skin";
	self.openSound = "fight_win_01";
	self.winBgPath = "/images/fight/xui_zd_bg_1.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/effects/uiEffects/ui_zdjs_sl_01", Lua_LoadFileType.UNITY3D);

	self.bIsWin = true;
	self.bIsShowHurtBtn = true;
	self.autoNextLangId = 302011;
end

function Lua_ClimbTowerFightWinWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.btnLeft:addClickFuntion(self, self.onLeftClick);
	self.btnRight:addClickFuntion(self, self.onRightClick);
end

function Lua_ClimbTowerFightWinWindow:dispose()
	Lua_CommonUtil.removeTimer(self, self.hide);
	self:clearRewardList();
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ClimbTowerFightWinWindow:showWin(param)
	self:superCall("showWin", param);

	self.data = DataCenter.climbTowerUtil:getTowerConfig(param.stage_id);
	local vo = DataCenter.climbTowerData:getTowerVoById(self.data.index);
	self.nameText.text = LanUtil.StringProfile(vo.name, Lua_SpaceDefine.SPACE, self.data.name);
	if self.data.storey >= vo.nextFightCond then
		self.operateVal = 1;
		self.btnRight:setLangValue(201028)
	else
		self.operateVal = 2;
		self.btnRight:setLangValue(201027)
	end

	self:updateRewards(param.item_list);

	self.bIsShowCountTime = true;
	self.bAutoNextFight = self.data.next and self.data.next > 0 and vo.autoNextFight > 0 and self.data.storey > vo.autoNextFight;
	self:initCountTime();
end

function Lua_ClimbTowerFightWinWindow:updateRewards(itemList)
	if itemList == nil or #itemList <= 0 then
		self:clearRewardList();
		return;
	end

	local tab = DataCenter.packData:getRewardDic(itemList);
	local arr = DataCenter.packData:getRewardList(tab);
	if self.rewardList == nil then
		local len = arr:getSize();
		if len > 4 then
			self.rewardList = Lua_DragList.new(self.content, 608, 152, Lua_AxisDefine.Horizontal);
		else
			self.rewardList = Lua_DragList.new(self.content, len * 135, 152, Lua_AxisDefine.Horizontal);
		end
		self.rewardList:setLocation(0, -270, 0);
		self.rewardList:setListCell(Lua_FightResultRewardItem, 135, 152, 1);
	end
	self.rewardList:setArrayData(arr);
	self.rewardList.canDrag = not self.rewardList.isTheEnd;
end

function Lua_ClimbTowerFightWinWindow:clearRewardList()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
end

function Lua_ClimbTowerFightWinWindow:onLeftClick(go)
	if self.data then
		local vo = DataCenter.climbTowerData:getTowerVoById(self.data.index);
		if Lua_WindowUtil.isWindowShowing(vo.windowName) then
			self:hide();
		else
			DataCenter.funcPathUtil:gotoFunction(vo.pathId, true, false, "Lua_ClimbTowerEntranceWindow")
		end
	else
		self:hide();
	end
end

function Lua_ClimbTowerFightWinWindow:onRightClick(go)
	if self.clickTime and getTime() - self.clickTime < 1 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();	
	
	if self.data and self.operateVal == 1 then -- 挑战下一层
		local vo = DataCenter.climbTowerData:getTowerVoById(self.data.index);
		if self.data.next and self.data.next > 0 then
			if vo.isLimit == true then
				OperateAlert.showLangValue(201001);
			else
				self:onAutoFight()
				return
			end
		else
			OperateAlert.showLangValue(201021);
		end
	end
	self:hide();
end

function Lua_ClimbTowerFightWinWindow:onAutoFight()
	local vo = DataCenter.climbTowerData:getTowerVoById(self.data.index);
	local lineup_type = Lua_FightTemplateConfigData.getConfigData(self.showData.template_id).lineup_type;
	if DataCenter.heroLineupData:getLineupHeroTotalNum(lineup_type) < 1 then
		OperateAlert.show(LanUtil.formateStr(201029, vo.name));
		self:hide();
		return;
	end

	DataCenter.funcPathUtil:clearFightRecordFuncPath(self.recordId);
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sStartFight(self.showData.template_id, self.data.next);
	if not Lua_WindowUtil.isWindowShowing(vo.windowName) then
		local temp = DataCenter.fightData:getRecordVoById(DataCenter.fightData._curPlayFightRecordId)
		if temp == nil or temp.templateId ~= vo.fight_id then
			local config = DataCenter.climbTowerUtil:getTowerConfig(self.data.next);
			OperateAlert.show(LanUtil.formateStr(201022, vo.name, config.name));
			self:hide();
			return;
		end
	end
	Lua_CommonUtil.delayCall(5, self, self.hide); -- 容错处理
end