-- 神域试炼特殊关卡结算界面
checkRequire("Lua_FightResultBaseWindow");
Lua_DivineDomainTrialSpecialTrialWinWindow = class("Lua_DivineDomainTrialSpecialTrialWinWindow", Lua_FightResultBaseWindow)
function Lua_DivineDomainTrialSpecialTrialWinWindow:ctor()
	self:superCall("ctor");
	self.windowName = "Lua_DivineDomainTrialSpecialTrialWinWindow";
	self.skinName = "DivineDomainTrialSpecialTrialWinWindow_skin";
	self.openSound = "fight_win_01";
	self.winBgPath = "/images/fight/xui_zd_bg_1.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/effects/uiEffects/ui_zdjs_sl_01", Lua_LoadFileType.UNITY3D);
	
	self.bIsWin = true;
	self.bIsShowCountTime = true;
	self.bIsShowHurtBtn = true;
end

function Lua_DivineDomainTrialSpecialTrialWinWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.monsterIcon = Lua_ItemIcon.new(self.content);
	self.monsterIcon:setLocation(-194, -124);
	self.monsterIcon:setScale(0.6, 0.6);

	self.rewardList = Lua_DragList.new(self.content, 556, 196, Lua_AxisDefine.Vertical);
	self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4);
	self.rewardList:setLocation(0, -366);

	self.btnBack:addClickFuntion(self, self.onBtnBackClick);
	self.btnSure:addClickFuntion(self, self.hide);
end

function Lua_DivineDomainTrialSpecialTrialWinWindow:hide()
	Lua_MsgUtil.callFunc("DIVINEDOMAIN_TRIAL_OPENTIP_WINS", true);
	self:superCall("hide");
end

function Lua_DivineDomainTrialSpecialTrialWinWindow:dispose()
	if self.monsterIcon ~= nil then
		self.monsterIcon:dispose();
		self.monsterIcon = nil;
	end
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	-- self:clearRewardList();
	self:superCall("dispose");
end

function Lua_DivineDomainTrialSpecialTrialWinWindow:showWin(param)
	self:superCall("showWin", param);

	local templateConfig = Lua_FightTemplateConfigData.getConfigData(param.template_id);
	self.nameText.text = templateConfig.title;

	if Lua_WindowUtil.isWindowShowing("Lua_DivineDomainTrialMainWindow") or DataCenter.funcPathUtil:haveFightRecordFuncPath(param.record_id) then
		self.btnBack:setEnable(false);
		self.btnSure:setLocation(0, -536, 0);
	else
		self.btnBack:setEnable(true);
		self.btnSure:setLocation(169, -536, 0);
	end

	local levelId = param.stage_id;
	local cfg = DataCenter.divineDomainTrialUtil:getDivineDomainTrialLevelConfig(levelId);
	if cfg == nil then
		return;
	end

	self.trialId = cfg.index;

	cfg = DataCenter.divineDomainTrialUtil:getDivineDomainTrialConfig(self.trialId);
	local monsterVo = Lua_HeroVo.new(cfg.hero_id);
	self.monsterIcon:setData(monsterVo)
	self.monsterIcon:setIconImg(monsterVo.avatar_atlas_1, monsterVo.avatar_sprite_1)
	self.monsterIcon:setIconBg(nil);
	self.boxIcon:setAltas("common_altas_4", "ui_sq_window_017");

	local bLastLevel = DataCenter.divineDomainTrialUtil:checkLastLevel(levelId);
	if bLastLevel and param.is_new_hurt == 1 then
		self.hurtTitle:setAltas("fight_atlas_2", "xui_zd_word_11");
	else
		self.hurtTitle:setAltas("fight_atlas_2", "xui_zd_word_10");
	end

	self:updateShowInfo(bLastLevel);
end

function Lua_DivineDomainTrialSpecialTrialWinWindow:updateShowInfo(bLastLevel)
	local hurt = self.showData.hurt_collect;
	local list = hurt.hurt_collect_list;
	if list == nil then
		return;
	end

	local idx = -1;
	local maxRot = -1;
	for i = 1, #list do
		if list[i].rotation > maxRot then
			maxRot = list[i].rotation;
			idx = i;
		end
	end

	-- local attackList = list[idx].attacker_hurt_collect;
	local defendList = list[idx].defender_hurt_collect;
	local curHP, totalHP = self:getHPRadio(defendList);

	local hurtTipStr;
	local resultStr;
	if bLastLevel then
		self.stepText.text = nil;
		self.rewardList:setEnable(false);
		self.rewardBg:setEnable(false);
		local totalHurt = self:getBossHurt(defendList);
		self.hurtBar:setMaxValue(totalHP);
		self.hurtBar:setValue(totalHurt);
		self.hurtBar:setText(LanUtil.formateStr(764047, totalHurt, totalHP));

		hurtTipStr = LanUtil.formateStr(764048, self.showData.max_hurt);

		local cfg = DataCenter.divineDomainTrialUtil:getDivineDomainTrialConfig(self.trialId);
		resultStr = cfg.fight_tip;
	else
		local radio = curHP / totalHP;
		radio = string.format("%.2f", radio) * 100;
		self.hurtBar:setMaxValue(totalHP);
		self.hurtBar:setValue(curHP);
		self.hurtBar:setText(radio.."%");

		local lastHurtValue = tonumber(self.showData.fight_hurt); -- 上次进场伤害
		local validValue = (totalHP - lastHurtValue - curHP) / (totalHP - lastHurtValue); --lastHurtValue ~= 0 and (lastHurtValue - curHP) / lastHurtValue or 0;
		radio = string.format("%.2f", validValue) * 100;

		self.stepText.text = LanUtil.formateStr(764049, radio);
		self.rewardList:setArrayData(self.showData.item_list);
		self.rewardList:setEnable(true);
		self.rewardBg:setEnable(true);
	end

	self.hurtText.text = hurtTipStr;
	self.rewardText.text = resultStr;
end

function Lua_DivineDomainTrialSpecialTrialWinWindow:getHPRadio(list)
	local curHP, totalHP = 0, 0;
	if list ~= nil then
		for i = 1, #list do
			curHP = curHP + tonumber(list[i].health);
			totalHP = totalHP + tonumber(list[i].max_health);
		end
	end
	return curHP, totalHP;
end

function Lua_DivineDomainTrialSpecialTrialWinWindow:getBossHurt(list)
	if list ~= nil then
		for i = 1, #list do
			if list[i].type == 5 then
				return tonumber(list[i].bear_hurt);
			end
		end
	end
	return 0;
end

function Lua_DivineDomainTrialSpecialTrialWinWindow:onBtnBackClick(go)
	DataCenter.funcPathUtil:gotoFunction(1142, true, false);
end