checkRequire("Lua_FightResultBaseWindow");
Lua_MainLineFightWinWindow = class("Lua_MainLineFightWinWindow", Lua_FightResultBaseWindow);
function Lua_MainLineFightWinWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_MainLineFightWinWindow";
	self.skinName = "MainLineFightWinWindow_skin";
	self.winBgPath = "/images/fight/xui_zd_bg_1.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/effects/uiEffects/ui_zdjs_sl_01", Lua_LoadFileType.UNITY3D);
	self.openSound = "fight_win_01";

	self.bIsWin = true;
	self.bIsShowHurtBtn = true;
	self.bCloseOther = false;
	self.bValue = true;
end

function Lua_MainLineFightWinWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.expBar.typeValue = 3;
    self.expBar.fillMethodValue = 0;
    self.expBar.fillOrigin = 0;
	self.btnLeft:addClickFuntion(self, self.hide);
	self.btnRight:addClickFuntion(self, self.onBtnRightClick);
end

function Lua_MainLineFightWinWindow:dispose()
	self:recordMainLineResult();
	if self.showData ~= nil and not self.bValue then
		local iconId = DataCenter.mainMenuData.selectMainIconId;
		local vo = DataCenter.funcPathUtil:getFuncPathVo(1005);
		if iconId ~= Lua_MenuViewDefine.ICON_MAINLINE or not vo.isShowing then
			DataCenter.funcPathUtil:gotoFunction(1005, self.bCloseOther, false, "Lua_HookIncomeChangeWindow")
		end
		Lua_WindowUtil.openWin("Lua_HookIncomeChangeWindow", Lua_WinParam.ACTION_OPEN, self.showData.stage_id);
	end
	self:stopBarTimer();
	self:clearRewardList();
	self:superCall("dispose");
end

function Lua_MainLineFightWinWindow:showWin(param)
	self:superCall("showWin", param);

	local player = DataCenter.fightData:getFightPlayerById(self.recordId);
	if player and player.bRunBack then
		self.bRunBack = true;
	else
		self.bRunBack = false;
	end

	local config = Lua_MainLineCheckpointConfigData.getConfig(param.stage_id);
	local chapterCfg = Lua_MainLineChapterConfigData.getConfig(config.chapter_id);
	self.nextStageId = config.next_game_level_id;
	self.nameText.text = chapterCfg.name..config.name;

	if not DataCenter.funcOpenData:isOpened(10238) or config.next_game_level_id == 0 or config.bResultPlot then
		self.operateVal = 2;
		self.btnRight:setLangValue(307052); -- 返回冒险
	else
		local nextCfg = Lua_MainLineCheckpointConfigData.getConfig(config.next_game_level_id);
		-- if nextCfg.is_boss == 1 or nextCfg.open_level > DataCenter.roleData.level then
		if nextCfg.open_level > DataCenter.roleData.level then
			self.operateVal = 2;
			self.btnRight:setLangValue(307052); -- 返回冒险
		else
			local chapter_id = Mathf.Floor(config.next_game_level_id / 10000);
			if chapter_id == config.chapter_id then -- 下一关
				self.operateVal = 1;
				self.btnRight:setLangValue(307044);
			else -- 下一章
				self.operateVal = 2;
				self.btnRight:setLangValue(307043);
			end
		end
	end

	local addExp = 0;
	if param.item_list ~= nil then
		local obj;
		for i = 1, #param.item_list do
			obj = param.item_list[i];
			if obj.id == Lua_ResourcesDefine.ROLE_EXP then
				addExp = addExp + obj.amount;
			end
		end
	end
	self:setRoleInfo(param.role_info.level, param.role_info.exp, addExp);

	self:updateRewards(param.item_list);

	self.bIsShowCountTime = true;
	local value = DataCenter.mainLineUtil.autoNextFight;
	self.bAutoNextFight = self.operateVal == 1 and value > 0 and param.stage_id > value;
	self:initCountTime();
end

function Lua_MainLineFightWinWindow:setRoleInfo(level, exp, addExp)
	self.levelText.text = LanUtil.formateStr(307055, tostring(level));
	if DataCenter.roleData:checkMaxLv(level) == true then
		self.expBar:setMaxValue(1);
		self.expBar:setValue(1);
		self.expBar:setLangValue(307049);
	else
		self.level = level;
		self.exp = exp;
		self.addExp = addExp;
		self.addExpStep = self.addExp / 1.5;
		self.maxExp = DataCenter.roleUtil:getLevelExp(level);
		
		self.expBar:setMaxValue(self.maxExp);
		self.expBar:setValue(self.exp);
		self.expBar:setText(LanUtil.formateStr(10044, tostring(self.exp), tostring(self.maxExp)));

		if self.addExp > 0 then
			self.startTime = getTime();
			self:startBarTimer();
		end
	end
end

function Lua_MainLineFightWinWindow:startBarTimer()
	if self.bBarTimer ~= true then
		self.bBarTimer = true;
		self:addTimer("Lua_MainLineFightWinWindow", 0.01, self, self.onBarTimer, nil, -1);
	end
end

function Lua_MainLineFightWinWindow:stopBarTimer()
	if self.bBarTimer == true then
		self.bBarTimer = false;
		self:removeTimer(self, self.onBarTimer);
	end
end

function Lua_MainLineFightWinWindow:onBarTimer()
	local t = getTime();
	local deltaTime = t - self.startTime;
	self.startTime = t;
	local bBarEnd = self:showBarProgress(deltaTime);
	if bBarEnd == true then
		self:stopBarTimer();
	end
end

function Lua_MainLineFightWinWindow:showBarProgress(deltaTime)
	if self.addExp <= 0 then
		return true;
	end

	local num = self.addExpStep * deltaTime;
	self.addExp = self.addExp - num;
	if self.addExp <= 0 then
		num = num + self.addExp;
	end
	self.exp = self.exp + num;

	self.maxExp = DataCenter.roleUtil:getLevelExp(self.level);
	if self.maxExp <= self.exp then
		self.exp = self.exp - self.maxExp;
		self.level = self.level + 1;
		self.maxExp = DataCenter.roleUtil:getLevelExp(self.level);
	end

	if self.level >= Lua_CommonUtil.getCommonConfig("role_max_level", 1) then
		self.expBar:setLangValue(307049);
		self.expBar:setMaxValue(1);
		self.expBar:setValue(1);
	else
		num = string.format("%.0f", self.exp);
		self.expBar:setMaxValue(self.maxExp);
		self.expBar:setText(LanUtil.formateStr(10044, num, tostring(self.maxExp)));
		self.expBar:setPercent(self.exp / self.maxExp);
	end

	self.levelText.text = LanUtil.formateStr(307055, tostring(self.level));
	return false;
end

function Lua_MainLineFightWinWindow:updateRewards(itemList)
	if itemList == nil or #itemList <= 0 then
		self:clearRewardList();
		return;
	end

	local tab = DataCenter.packData:getRewardDic(itemList);
	local arr = DataCenter.packData:getRewardList(tab);
	if self.rewardList == nil then
		local len = arr:getSize();
		if len > 4 then
			self.rewardBg:SetDimensions(720, 266);
			self.rewardList = Lua_DragList.new(self.showObject_3, 556, 240, Lua_AxisDefine.Vertical);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4);
		else
			self.rewardBg:SetDimensions(720, 176);
			self.rewardList = Lua_DragList.new(self.showObject_3, len * 124 + (len - 1) * 20, 160, Lua_AxisDefine.Vertical);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4);
		end
		self.rewardList:setCellSpacing(20, 0);
		-- self.rewardList:setRectAnchor(7);
		self.rewardList:setRectPivot(1)
		self.rewardList:setLocation(0, -208, 0);
		self.rewardList.tweenId = 2007;
	end
	self.rewardList:setArrayData(arr);
	self.rewardList.canDrag = not self.rewardList.isTheEnd;
end

function Lua_MainLineFightWinWindow:clearRewardList()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
end

function Lua_MainLineFightWinWindow:onBtnRightClick(go)
	if self.clickTime and getTime() - self.clickTime < 1 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();	
	
	if self.operateVal == 1 then -- 下一关
		self:onAutoFight();
	else
		self.bValue = false;
		if self.operateVal == 2 then -- 下一章/返回冒险界面
			if not Lua_WindowUtil.isWindowShowing("Lua_MainLineWindow") then
				self.bCloseOther = true
			end
		end
		self:hide()
	end
end

function Lua_MainLineFightWinWindow:onAutoFight()
	DataCenter.mainLineData.bFightRunBack = self.bRunBack;
	DataCenter.funcPathUtil:clearFightRecordFuncPath(self.recordId);
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sStartFight(self.templateId, self.nextStageId);
	OperateAlert.showLangValue(307045);
	if self.bRunBack or DataCenter.mainMenuData.selectMainIconId ~= Lua_MenuViewDefine.ICON_MAINLINE or not Lua_WindowUtil.isWindowShowing("Lua_MainLineWindow") then
		self:hide();
	end
end