checkRequire("Lua_FightResultBaseWindow")
checkRequire("Lua_PeakDuelUpgradeItem")
Lua_PeakDuelFightWinWindow = class("Lua_PeakDuelFightWinWindow", Lua_FightResultBaseWindow)
function Lua_PeakDuelFightWinWindow:ctor()
	self:superCall("ctor")

	self.windowName = "Lua_PeakDuelFightWinWindow"
	self.skinName = "PeakDuelResultWindow_skin"
	self.winBgPath = "/images/fight/xui_zd_bg_1.jpg"
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG)
	self:addPreLoadRes("/effects/uiEffects/ui_zdjs_sl_01", Lua_LoadFileType.UNITY3D)
	self.openSound = "fight_win_01"
	
	self.bIsWin = true
	self.bIsShowCountTime = true
	self.bIsShowHurtBtn = true
end

function Lua_PeakDuelFightWinWindow:buildShowItem()
	self:superCall("buildShowItem")

	self.btnBack:addClickFuntion(self, self.onBackClick)
	self.btnSure:addClickFuntion(self, self.hide)
end

function Lua_PeakDuelFightWinWindow:dispose()
	if self.upgradeArr then
		self.upgradeArr:dispose()
		self.upgradeArr:clear()
		self.upgradeArr = nil
	end
	self.upResultDic = nil
	self:clearRewardList()
	self:superCall("dispose")
end

function Lua_PeakDuelFightWinWindow:showWin(param)
	self:superCall("showWin", param)

	local prevCfg = DataCenter.peakDuelUtil:getSegmentInfoByid(param.old_segment_lvl)
	local config = DataCenter.peakDuelUtil:getSegmentInfoByid(param.segment_lvl)
	if param.segment_lvl ~= param.old_segment_lvl then -- 段位发生变化
		self.prevObject:SetActive(true)
		self.curIcon:setLocation(125, -25, 0)
		self.curBg:setLocation(125, -85, 0)
		self.curText:setLocation(125, -85, 0)

		self.prevIcon:setAltas("peak_duel_altas", prevCfg.icon)
		self.prevText.text = prevCfg.name
	else
		self.prevObject:SetActive(false)
		self.curIcon:setLocation(0, -25, 0)
		self.curBg:setLocation(0, -85, 0)
		self.curText:setLocation(0, -85, 0)
	end

	self.curIcon:setAltas("peak_duel_altas", config.icon)
	self.curText.text = config.name

	if param.is_upgrade == 1 then -- 升段中
		self.barObject:SetActive(false)
		self.upResultDic = {} -- key:升段赛的第几场 value:战斗结果 1胜利 0失败
		if param.upgrade_result then
			local obj
			for i = 1, #param.upgrade_result do
				obj = param.upgrade_result[i]
				self.upResultDic[obj.key] = obj.value
			end
		end
		self:showUpgrade(prevCfg.upgrade_segment_cond[1])
	else
		local maxValue = prevCfg.segment_lvl_cond
		if param.old_segment_lvl > param.segment_lvl then
			maxValue = config.segment_lvl_cond
		end
		self.barObject:SetActive(true)
		self.barText.text = param.segment_lvl_exp.."/"..maxValue
		self.expBar:createSecondBar("peak_duel_altas", "xui_dfs_Progress_1_f2")
		self.expBar:setSecondMaxValue(maxValue)
		self.expBar:setSecondValue(param.segment_lvl_exp)
		self.expBar:setMaxValue(maxValue)
		self.expBar:setValue(param.cache_exp)
	end

	local str
	if param.exp_change == 0 then
		str = LanUtil.getValue(202996)
	elseif param.exp_change > 0 then
		str = LanUtil.formateStr(10059, tostring(param.exp_change))
		str = Lua_ColorDefine.getColorStr(Lua_ColorDefine.GREEN_STR_2, str)
		str = param.segment_lvl_exp..str
	else
		str = LanUtil.formateStr(10042, tostring(param.exp_change))
		str = Lua_ColorDefine.getColorStr(Lua_ColorDefine.RED_STR_2, str)
		str = param.segment_lvl_exp..str
	end
	self.expText.text = str

	if param.score_change == 0 then
		str = LanUtil.getValue(202996)
	elseif param.score_change > 0 then
		str = LanUtil.formateStr(10059, tostring(param.score_change))
		str = Lua_ColorDefine.getColorStr(Lua_ColorDefine.GREEN_STR_2, str)
		str = param.score..str
	else
		str = LanUtil.formateStr(10042, tostring(param.score_change))
		str = Lua_ColorDefine.getColorStr(Lua_ColorDefine.RED_STR_2, str)
		str = param.score..str
	end
	self.scoreText.text = str

	self:updateRewards(param.item_list)
end

function Lua_PeakDuelFightWinWindow:showUpgrade(dataLen)
	if self.upgradeArr == nil then
		self.upgradeArr = Array()
	end
	local len = self.upgradeArr:getSize()
	local maxLen = dataLen > len and dataLen or len
	local item
	for i = 1, maxLen do
		item = self.upgradeArr[i]
		if i > dataLen then
			if item then
				item:setEnable(false)
			end
		else
			if item == nil then
				item = Lua_PeakDuelUpgradeItem.new(self.showObject_1)
				self.upgradeArr:add(item)
			else
				item:setEnable(true)
			end
			item:setData(self.upResultDic[i])
		end
	end
	if dataLen > 0 then
		local space = 80
		local w
		local posX
		for i = 1, dataLen do
			item = self.upgradeArr[i]

			w = -(space * dataLen) / 2 + space / 2
			posX = ((i - 1) % dataLen) * space + w
			item:setLocation(posX, -130, 0)
		end
	end
end

function Lua_PeakDuelFightWinWindow:updateRewards(itemList)
	if itemList == nil or #itemList <= 0 then
		self.rewardTitle:setEnable(false)
		self:clearRewardList()
		return
	end

	self.rewardTitle:setEnable(true)
	local tab = DataCenter.packData:getRewardDic(itemList)
	local arr = DataCenter.packData:getRewardList(tab)
	if self.rewardList == nil then
		local len = arr:getSize()
		if len > 4 then
			self.rewardList = Lua_DragList.new(self.showObject_2, 556, 240, Lua_AxisDefine.Vertical)
			self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4)
		else
			self.rewardList = Lua_DragList.new(self.showObject_2, len * 124 + (len - 1) * 20, 160, Lua_AxisDefine.Vertical)
			self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4)
		end
		self.rewardList:setCellSpacing(20, 0)
		self.rewardList:setRectPivot(1)
		self.rewardList:setLocation(0, -325, 0)
		self.rewardList.tweenId = 2007
	end
	self.rewardList:setArrayData(arr)
	self.rewardList.canDrag = not self.rewardList.isTheEnd
end

function Lua_PeakDuelFightWinWindow:clearRewardList()
	if self.rewardList then
		self.rewardList:dispose()
		self.rewardList = nil
	end
end

function Lua_PeakDuelFightWinWindow:onBackClick(go)
	DataCenter.funcPathUtil:gotoFunction(1025, true, false)
end