checkRequire("Lua_FightResultBaseWindow");
Lua_TimeSpaceRaceFightWinWindow = class("Lua_TimeSpaceRaceFightWinWindow", Lua_FightResultBaseWindow)
function Lua_TimeSpaceRaceFightWinWindow:ctor()
	self:superCall("ctor")

	self.windowName = "Lua_TimeSpaceRaceFightWinWindow";
	self.skinName = "TimeSpaceRaceFightResultWindow_skin";
	self.winBgPath = "/images/fight/xui_zd_bg_1.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/effects/uiEffects/ui_zdjs_sl_01", Lua_LoadFileType.UNITY3D);
	self.openSound = "fight_win_01";
	
	self.bIsWin = true;
	self.bIsShowCountTime = true;
	self.bIsShowHurtBtn = true;
end

function Lua_TimeSpaceRaceFightWinWindow:buildShowItem()
	self:superCall("buildShowItem");
	Lua_WindowUtil.openWin("Lua_TimeSpaceRaceLineupWindow", Lua_WinParam.ACTION_CLOSE);

	self.leftAvatar = Lua_AvatarItem.new(self.content);
	self.leftAvatar:setScale(0.8, 0.8, 1);
	self.leftAvatar:setLocation(-145, -93, 0);

	self.rightAvatar = Lua_AvatarItem.new(self.content);
	self.rightAvatar:setScale(0.8, 0.8, 1);
	self.rightAvatar:setLocation(145, -93, 0);

	self.btnBack:addClickFuntion(self, self.onBackClick);
	self.btnSure:addClickFuntion(self, self.hide);
end

function Lua_TimeSpaceRaceFightWinWindow:dispose()
	self:clearRewardList();
	if self.leftAvatar then
		self.leftAvatar:dispose();
		self.leftAvatar = nil;
	end
	if self.rightAvatar then
		self.rightAvatar:dispose();
		self.rightAvatar = nil;
	end
	self:superCall("dispose");
end

function Lua_TimeSpaceRaceFightWinWindow:showWin(param)
	self:superCall("showWin", param);

	self:updateShowInfo();
	self:updateRewards(param.item_list);
end

function Lua_TimeSpaceRaceFightWinWindow:updateShowInfo()
	local info = self.showData.hurt_collect.hurt_collect_list[1].attacker;
	self.leftName.text = info.name;
	self.leftAvatar:setRoleDressUp(info.dress_info);
	self.leftAvatar:setRoleLevel(info.level);

	info = self.showData.hurt_collect.hurt_collect_list[1].defender;
	self.rightName.text = info.name;
	self.rightAvatar:setRoleDressUp(info.dress_info);
	self.rightAvatar:setRoleLevel(info.level);

	info = self.showData.time_space_fight_settle;
	local config = DataCenter.timeSpaceRaceUtil:getTimeSpaceConfig(info.type);
	self.nameText.text = config.name;

	local value = info.old_att_rank - info.new_att_rank;
	if value == 0 then
		self.leftRank.text = info.new_att_rank..LanUtil.getValue(770022);
	else
		local str;
		if value > 0 then
			str = LanUtil.formateStr(10059, tostring(value));
			str = Lua_ColorDefine.getColorStr("65BE7E", str);
		else
			str = LanUtil.formateStr(10048, tostring(value));
			str = Lua_ColorDefine.getColorStr("EE917F", str);
		end
		self.leftRank.text = info.new_att_rank..str;
	end

	value = info.old_def_rank - info.new_def_rank;
	if value == 0 then
		self.rightRank.text = info.new_def_rank..LanUtil.getValue(770022);
	else
		local str;
		if value > 0 then
			str = LanUtil.formateStr(10059, tostring(value));
			str = Lua_ColorDefine.getColorStr("65BE7E", str);
		else
			str = LanUtil.formateStr(10048, tostring(value));
			str = Lua_ColorDefine.getColorStr("EE917F", str);
		end
		self.rightRank.text = info.new_def_rank..str;
	end
end

function Lua_TimeSpaceRaceFightWinWindow:updateRewards(itemList)
	if itemList == nil or #itemList <= 0 then
		self:clearRewardList();
		return;
	end

	local tab = DataCenter.packData:getRewardDic(itemList);
	local arr = DataCenter.packData:getRewardList(tab);
	if self.rewardList == nil then
		local len = arr:getSize();
		if len > 4 then
			self.rewardBg:SetDimensions(720, 266);
			self.rewardList = Lua_DragList.new(self.content, 556, 240, Lua_AxisDefine.Vertical);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4);
		else
			self.rewardBg:SetDimensions(720, 176);
			self.rewardList = Lua_DragList.new(self.content, len * 124 + (len - 1) * 20, 160, Lua_AxisDefine.Vertical);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 124, 160, 4);
		end
		self.rewardList:setCellSpacing(20, 0);
		self.rewardList:setRectPivot(1)
		self.rewardList:setLocation(0, -299, 0);
	end
	self.rewardList:setArrayData(arr);
	self.rewardList.canDrag = not self.rewardList.isTheEnd;
end

function Lua_TimeSpaceRaceFightWinWindow:clearRewardList()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
end

function Lua_TimeSpaceRaceFightWinWindow:onBackClick(go)
	DataCenter.funcPathUtil:gotoFunction(1152, true, false);
end